#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.KbdishSpecGroup import KbdishSpecGroup


class KoubeiCateringDishSpecgroupSyncModel(object):

    def __init__(self):
        self._create_user = None
        self._kbdish_spec_group = None
        self._syn_type = None
        self._update_user = None

    @property
    def create_user(self):
        return self._create_user

    @create_user.setter
    def create_user(self, value):
        self._create_user = value
    @property
    def kbdish_spec_group(self):
        return self._kbdish_spec_group

    @kbdish_spec_group.setter
    def kbdish_spec_group(self, value):
        if isinstance(value, KbdishSpecGroup):
            self._kbdish_spec_group = value
        else:
            self._kbdish_spec_group = KbdishSpecGroup.from_alipay_dict(value)
    @property
    def syn_type(self):
        return self._syn_type

    @syn_type.setter
    def syn_type(self, value):
        self._syn_type = value
    @property
    def update_user(self):
        return self._update_user

    @update_user.setter
    def update_user(self, value):
        self._update_user = value


    def to_alipay_dict(self):
        params = dict()
        if self.create_user:
            if hasattr(self.create_user, 'to_alipay_dict'):
                params['create_user'] = self.create_user.to_alipay_dict()
            else:
                params['create_user'] = self.create_user
        if self.kbdish_spec_group:
            if hasattr(self.kbdish_spec_group, 'to_alipay_dict'):
                params['kbdish_spec_group'] = self.kbdish_spec_group.to_alipay_dict()
            else:
                params['kbdish_spec_group'] = self.kbdish_spec_group
        if self.syn_type:
            if hasattr(self.syn_type, 'to_alipay_dict'):
                params['syn_type'] = self.syn_type.to_alipay_dict()
            else:
                params['syn_type'] = self.syn_type
        if self.update_user:
            if hasattr(self.update_user, 'to_alipay_dict'):
                params['update_user'] = self.update_user.to_alipay_dict()
            else:
                params['update_user'] = self.update_user
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiCateringDishSpecgroupSyncModel()
        if 'create_user' in d:
            o.create_user = d['create_user']
        if 'kbdish_spec_group' in d:
            o.kbdish_spec_group = d['kbdish_spec_group']
        if 'syn_type' in d:
            o.syn_type = d['syn_type']
        if 'update_user' in d:
            o.update_user = d['update_user']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class PosSkuModel(object):

    def __init__(self):
        self._box_price = None
        self._sell_price = None
        self._sku_id = None
        self._sku_sort = None
        self._spec_code_01 = None
        self._spec_name_01 = None
        self._status = None

    @property
    def box_price(self):
        return self._box_price

    @box_price.setter
    def box_price(self, value):
        self._box_price = value
    @property
    def sell_price(self):
        return self._sell_price

    @sell_price.setter
    def sell_price(self, value):
        self._sell_price = value
    @property
    def sku_id(self):
        return self._sku_id

    @sku_id.setter
    def sku_id(self, value):
        self._sku_id = value
    @property
    def sku_sort(self):
        return self._sku_sort

    @sku_sort.setter
    def sku_sort(self, value):
        self._sku_sort = value
    @property
    def spec_code_01(self):
        return self._spec_code_01

    @spec_code_01.setter
    def spec_code_01(self, value):
        self._spec_code_01 = value
    @property
    def spec_name_01(self):
        return self._spec_name_01

    @spec_name_01.setter
    def spec_name_01(self, value):
        self._spec_name_01 = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.box_price:
            if hasattr(self.box_price, 'to_alipay_dict'):
                params['box_price'] = self.box_price.to_alipay_dict()
            else:
                params['box_price'] = self.box_price
        if self.sell_price:
            if hasattr(self.sell_price, 'to_alipay_dict'):
                params['sell_price'] = self.sell_price.to_alipay_dict()
            else:
                params['sell_price'] = self.sell_price
        if self.sku_id:
            if hasattr(self.sku_id, 'to_alipay_dict'):
                params['sku_id'] = self.sku_id.to_alipay_dict()
            else:
                params['sku_id'] = self.sku_id
        if self.sku_sort:
            if hasattr(self.sku_sort, 'to_alipay_dict'):
                params['sku_sort'] = self.sku_sort.to_alipay_dict()
            else:
                params['sku_sort'] = self.sku_sort
        if self.spec_code_01:
            if hasattr(self.spec_code_01, 'to_alipay_dict'):
                params['spec_code_01'] = self.spec_code_01.to_alipay_dict()
            else:
                params['spec_code_01'] = self.spec_code_01
        if self.spec_name_01:
            if hasattr(self.spec_name_01, 'to_alipay_dict'):
                params['spec_name_01'] = self.spec_name_01.to_alipay_dict()
            else:
                params['spec_name_01'] = self.spec_name_01
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PosSkuModel()
        if 'box_price' in d:
            o.box_price = d['box_price']
        if 'sell_price' in d:
            o.sell_price = d['sell_price']
        if 'sku_id' in d:
            o.sku_id = d['sku_id']
        if 'sku_sort' in d:
            o.sku_sort = d['sku_sort']
        if 'spec_code_01' in d:
            o.spec_code_01 = d['spec_code_01']
        if 'spec_name_01' in d:
            o.spec_name_01 = d['spec_name_01']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CertFields(object):

    def __init__(self):
        self._address = None
        self._birth = None
        self._certno = None
        self._expires = None
        self._expiresend = None
        self._expiresstart = None
        self._issuingauthority = None
        self._name = None
        self._number = None
        self._race = None
        self._renewalnum = None
        self._sex = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def birth(self):
        return self._birth

    @birth.setter
    def birth(self, value):
        self._birth = value
    @property
    def certno(self):
        return self._certno

    @certno.setter
    def certno(self, value):
        self._certno = value
    @property
    def expires(self):
        return self._expires

    @expires.setter
    def expires(self, value):
        self._expires = value
    @property
    def expiresend(self):
        return self._expiresend

    @expiresend.setter
    def expiresend(self, value):
        self._expiresend = value
    @property
    def expiresstart(self):
        return self._expiresstart

    @expiresstart.setter
    def expiresstart(self, value):
        self._expiresstart = value
    @property
    def issuingauthority(self):
        return self._issuingauthority

    @issuingauthority.setter
    def issuingauthority(self, value):
        self._issuingauthority = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def number(self):
        return self._number

    @number.setter
    def number(self, value):
        self._number = value
    @property
    def race(self):
        return self._race

    @race.setter
    def race(self, value):
        self._race = value
    @property
    def renewalnum(self):
        return self._renewalnum

    @renewalnum.setter
    def renewalnum(self, value):
        self._renewalnum = value
    @property
    def sex(self):
        return self._sex

    @sex.setter
    def sex(self, value):
        self._sex = value


    def to_alipay_dict(self):
        params = dict()
        if self.address:
            if hasattr(self.address, 'to_alipay_dict'):
                params['address'] = self.address.to_alipay_dict()
            else:
                params['address'] = self.address
        if self.birth:
            if hasattr(self.birth, 'to_alipay_dict'):
                params['birth'] = self.birth.to_alipay_dict()
            else:
                params['birth'] = self.birth
        if self.certno:
            if hasattr(self.certno, 'to_alipay_dict'):
                params['certno'] = self.certno.to_alipay_dict()
            else:
                params['certno'] = self.certno
        if self.expires:
            if hasattr(self.expires, 'to_alipay_dict'):
                params['expires'] = self.expires.to_alipay_dict()
            else:
                params['expires'] = self.expires
        if self.expiresend:
            if hasattr(self.expiresend, 'to_alipay_dict'):
                params['expiresend'] = self.expiresend.to_alipay_dict()
            else:
                params['expiresend'] = self.expiresend
        if self.expiresstart:
            if hasattr(self.expiresstart, 'to_alipay_dict'):
                params['expiresstart'] = self.expiresstart.to_alipay_dict()
            else:
                params['expiresstart'] = self.expiresstart
        if self.issuingauthority:
            if hasattr(self.issuingauthority, 'to_alipay_dict'):
                params['issuingauthority'] = self.issuingauthority.to_alipay_dict()
            else:
                params['issuingauthority'] = self.issuingauthority
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.number:
            if hasattr(self.number, 'to_alipay_dict'):
                params['number'] = self.number.to_alipay_dict()
            else:
                params['number'] = self.number
        if self.race:
            if hasattr(self.race, 'to_alipay_dict'):
                params['race'] = self.race.to_alipay_dict()
            else:
                params['race'] = self.race
        if self.renewalnum:
            if hasattr(self.renewalnum, 'to_alipay_dict'):
                params['renewalnum'] = self.renewalnum.to_alipay_dict()
            else:
                params['renewalnum'] = self.renewalnum
        if self.sex:
            if hasattr(self.sex, 'to_alipay_dict'):
                params['sex'] = self.sex.to_alipay_dict()
            else:
                params['sex'] = self.sex
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CertFields()
        if 'address' in d:
            o.address = d['address']
        if 'birth' in d:
            o.birth = d['birth']
        if 'certno' in d:
            o.certno = d['certno']
        if 'expires' in d:
            o.expires = d['expires']
        if 'expiresend' in d:
            o.expiresend = d['expiresend']
        if 'expiresstart' in d:
            o.expiresstart = d['expiresstart']
        if 'issuingauthority' in d:
            o.issuingauthority = d['issuingauthority']
        if 'name' in d:
            o.name = d['name']
        if 'number' in d:
            o.number = d['number']
        if 'race' in d:
            o.race = d['race']
        if 'renewalnum' in d:
            o.renewalnum = d['renewalnum']
        if 'sex' in d:
            o.sex = d['sex']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.JourneyLocation import JourneyLocation
from alipay.aop.api.domain.JourneyLocation import JourneyLocation
from alipay.aop.api.domain.OrderExtInfo import OrderExtInfo
from alipay.aop.api.domain.FunctionalService import FunctionalService
from alipay.aop.api.domain.UserInfomation import UserInfomation
from alipay.aop.api.domain.JourneyServiceChangeInfo import JourneyServiceChangeInfo
from alipay.aop.api.domain.JourneyMerchantInfo import JourneyMerchantInfo


class OrderJourneyElement(object):

    def __init__(self):
        self._arrival = None
        self._departure = None
        self._duration = None
        self._end_time = None
        self._end_time_desc = None
        self._ext_info = None
        self._functional_services = None
        self._passagers = None
        self._service_change_info = None
        self._service_provider = None
        self._start_time = None
        self._start_time_desc = None

    @property
    def arrival(self):
        return self._arrival

    @arrival.setter
    def arrival(self, value):
        if isinstance(value, JourneyLocation):
            self._arrival = value
        else:
            self._arrival = JourneyLocation.from_alipay_dict(value)
    @property
    def departure(self):
        return self._departure

    @departure.setter
    def departure(self, value):
        if isinstance(value, JourneyLocation):
            self._departure = value
        else:
            self._departure = JourneyLocation.from_alipay_dict(value)
    @property
    def duration(self):
        return self._duration

    @duration.setter
    def duration(self, value):
        self._duration = value
    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def end_time_desc(self):
        return self._end_time_desc

    @end_time_desc.setter
    def end_time_desc(self, value):
        self._end_time_desc = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        if isinstance(value, list):
            self._ext_info = list()
            for i in value:
                if isinstance(i, OrderExtInfo):
                    self._ext_info.append(i)
                else:
                    self._ext_info.append(OrderExtInfo.from_alipay_dict(i))
    @property
    def functional_services(self):
        return self._functional_services

    @functional_services.setter
    def functional_services(self, value):
        if isinstance(value, list):
            self._functional_services = list()
            for i in value:
                if isinstance(i, FunctionalService):
                    self._functional_services.append(i)
                else:
                    self._functional_services.append(FunctionalService.from_alipay_dict(i))
    @property
    def passagers(self):
        return self._passagers

    @passagers.setter
    def passagers(self, value):
        if isinstance(value, list):
            self._passagers = list()
            for i in value:
                if isinstance(i, UserInfomation):
                    self._passagers.append(i)
                else:
                    self._passagers.append(UserInfomation.from_alipay_dict(i))
    @property
    def service_change_info(self):
        return self._service_change_info

    @service_change_info.setter
    def service_change_info(self, value):
        if isinstance(value, JourneyServiceChangeInfo):
            self._service_change_info = value
        else:
            self._service_change_info = JourneyServiceChangeInfo.from_alipay_dict(value)
    @property
    def service_provider(self):
        return self._service_provider

    @service_provider.setter
    def service_provider(self, value):
        if isinstance(value, JourneyMerchantInfo):
            self._service_provider = value
        else:
            self._service_provider = JourneyMerchantInfo.from_alipay_dict(value)
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value
    @property
    def start_time_desc(self):
        return self._start_time_desc

    @start_time_desc.setter
    def start_time_desc(self, value):
        self._start_time_desc = value


    def to_alipay_dict(self):
        params = dict()
        if self.arrival:
            if hasattr(self.arrival, 'to_alipay_dict'):
                params['arrival'] = self.arrival.to_alipay_dict()
            else:
                params['arrival'] = self.arrival
        if self.departure:
            if hasattr(self.departure, 'to_alipay_dict'):
                params['departure'] = self.departure.to_alipay_dict()
            else:
                params['departure'] = self.departure
        if self.duration:
            if hasattr(self.duration, 'to_alipay_dict'):
                params['duration'] = self.duration.to_alipay_dict()
            else:
                params['duration'] = self.duration
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.end_time_desc:
            if hasattr(self.end_time_desc, 'to_alipay_dict'):
                params['end_time_desc'] = self.end_time_desc.to_alipay_dict()
            else:
                params['end_time_desc'] = self.end_time_desc
        if self.ext_info:
            if isinstance(self.ext_info, list):
                for i in range(0, len(self.ext_info)):
                    element = self.ext_info[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.ext_info[i] = element.to_alipay_dict()
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.functional_services:
            if isinstance(self.functional_services, list):
                for i in range(0, len(self.functional_services)):
                    element = self.functional_services[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.functional_services[i] = element.to_alipay_dict()
            if hasattr(self.functional_services, 'to_alipay_dict'):
                params['functional_services'] = self.functional_services.to_alipay_dict()
            else:
                params['functional_services'] = self.functional_services
        if self.passagers:
            if isinstance(self.passagers, list):
                for i in range(0, len(self.passagers)):
                    element = self.passagers[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.passagers[i] = element.to_alipay_dict()
            if hasattr(self.passagers, 'to_alipay_dict'):
                params['passagers'] = self.passagers.to_alipay_dict()
            else:
                params['passagers'] = self.passagers
        if self.service_change_info:
            if hasattr(self.service_change_info, 'to_alipay_dict'):
                params['service_change_info'] = self.service_change_info.to_alipay_dict()
            else:
                params['service_change_info'] = self.service_change_info
        if self.service_provider:
            if hasattr(self.service_provider, 'to_alipay_dict'):
                params['service_provider'] = self.service_provider.to_alipay_dict()
            else:
                params['service_provider'] = self.service_provider
        if self.start_time:
            if hasattr(self.start_time, 'to_alipay_dict'):
                params['start_time'] = self.start_time.to_alipay_dict()
            else:
                params['start_time'] = self.start_time
        if self.start_time_desc:
            if hasattr(self.start_time_desc, 'to_alipay_dict'):
                params['start_time_desc'] = self.start_time_desc.to_alipay_dict()
            else:
                params['start_time_desc'] = self.start_time_desc
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OrderJourneyElement()
        if 'arrival' in d:
            o.arrival = d['arrival']
        if 'departure' in d:
            o.departure = d['departure']
        if 'duration' in d:
            o.duration = d['duration']
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'end_time_desc' in d:
            o.end_time_desc = d['end_time_desc']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'functional_services' in d:
            o.functional_services = d['functional_services']
        if 'passagers' in d:
            o.passagers = d['passagers']
        if 'service_change_info' in d:
            o.service_change_info = d['service_change_info']
        if 'service_provider' in d:
            o.service_provider = d['service_provider']
        if 'start_time' in d:
            o.start_time = d['start_time']
        if 'start_time_desc' in d:
            o.start_time_desc = d['start_time_desc']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFincoreComplianceTemplateInstanceQueryModel(object):

    def __init__(self):
        self._biz_instance_id = None
        self._source_system_id = None
        self._tenant = None

    @property
    def biz_instance_id(self):
        return self._biz_instance_id

    @biz_instance_id.setter
    def biz_instance_id(self, value):
        self._biz_instance_id = value
    @property
    def source_system_id(self):
        return self._source_system_id

    @source_system_id.setter
    def source_system_id(self, value):
        self._source_system_id = value
    @property
    def tenant(self):
        return self._tenant

    @tenant.setter
    def tenant(self, value):
        self._tenant = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_instance_id:
            if hasattr(self.biz_instance_id, 'to_alipay_dict'):
                params['biz_instance_id'] = self.biz_instance_id.to_alipay_dict()
            else:
                params['biz_instance_id'] = self.biz_instance_id
        if self.source_system_id:
            if hasattr(self.source_system_id, 'to_alipay_dict'):
                params['source_system_id'] = self.source_system_id.to_alipay_dict()
            else:
                params['source_system_id'] = self.source_system_id
        if self.tenant:
            if hasattr(self.tenant, 'to_alipay_dict'):
                params['tenant'] = self.tenant.to_alipay_dict()
            else:
                params['tenant'] = self.tenant
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFincoreComplianceTemplateInstanceQueryModel()
        if 'biz_instance_id' in d:
            o.biz_instance_id = d['biz_instance_id']
        if 'source_system_id' in d:
            o.source_system_id = d['source_system_id']
        if 'tenant' in d:
            o.tenant = d['tenant']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class MybankCreditUserRoleCreateResponse(AlipayResponse):

    def __init__(self):
        super(MybankCreditUserRoleCreateResponse, self).__init__()
        self._ip_id = None
        self._ip_role_id = None

    @property
    def ip_id(self):
        return self._ip_id

    @ip_id.setter
    def ip_id(self, value):
        self._ip_id = value
    @property
    def ip_role_id(self):
        return self._ip_role_id

    @ip_role_id.setter
    def ip_role_id(self, value):
        self._ip_role_id = value

    def parse_response_content(self, response_content):
        response = super(MybankCreditUserRoleCreateResponse, self).parse_response_content(response_content)
        if 'ip_id' in response:
            self.ip_id = response['ip_id']
        if 'ip_role_id' in response:
            self.ip_role_id = response['ip_role_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayUserFamilyShareZmgoInitializeResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserFamilyShareZmgoInitializeResponse, self).__init__()
        self._family_sharing_link = None
        self._has_sharing = None
        self._shareable = None

    @property
    def family_sharing_link(self):
        return self._family_sharing_link

    @family_sharing_link.setter
    def family_sharing_link(self, value):
        self._family_sharing_link = value
    @property
    def has_sharing(self):
        return self._has_sharing

    @has_sharing.setter
    def has_sharing(self, value):
        self._has_sharing = value
    @property
    def shareable(self):
        return self._shareable

    @shareable.setter
    def shareable(self, value):
        self._shareable = value

    def parse_response_content(self, response_content):
        response = super(AlipayUserFamilyShareZmgoInitializeResponse, self).parse_response_content(response_content)
        if 'family_sharing_link' in response:
            self.family_sharing_link = response['family_sharing_link']
        if 'has_sharing' in response:
            self.has_sharing = response['has_sharing']
        if 'shareable' in response:
            self.shareable = response['shareable']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class MybankPaymentTradeAccountSubvirtualcardCreateResponse(AlipayResponse):

    def __init__(self):
        super(MybankPaymentTradeAccountSubvirtualcardCreateResponse, self).__init__()
        self._prim_card_no = None
        self._sub_virtual_card_name = None
        self._sub_virtual_card_no = None

    @property
    def prim_card_no(self):
        return self._prim_card_no

    @prim_card_no.setter
    def prim_card_no(self, value):
        self._prim_card_no = value
    @property
    def sub_virtual_card_name(self):
        return self._sub_virtual_card_name

    @sub_virtual_card_name.setter
    def sub_virtual_card_name(self, value):
        self._sub_virtual_card_name = value
    @property
    def sub_virtual_card_no(self):
        return self._sub_virtual_card_no

    @sub_virtual_card_no.setter
    def sub_virtual_card_no(self, value):
        self._sub_virtual_card_no = value

    def parse_response_content(self, response_content):
        response = super(MybankPaymentTradeAccountSubvirtualcardCreateResponse, self).parse_response_content(response_content)
        if 'prim_card_no' in response:
            self.prim_card_no = response['prim_card_no']
        if 'sub_virtual_card_name' in response:
            self.sub_virtual_card_name = response['sub_virtual_card_name']
        if 'sub_virtual_card_no' in response:
            self.sub_virtual_card_no = response['sub_virtual_card_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMsaasMediarecogMmtcaftscvDeviceBindModel(object):

    def __init__(self):
        self._device_id = None
        self._isv_pid = None
        self._isv_tid = None

    @property
    def device_id(self):
        return self._device_id

    @device_id.setter
    def device_id(self, value):
        self._device_id = value
    @property
    def isv_pid(self):
        return self._isv_pid

    @isv_pid.setter
    def isv_pid(self, value):
        self._isv_pid = value
    @property
    def isv_tid(self):
        return self._isv_tid

    @isv_tid.setter
    def isv_tid(self, value):
        self._isv_tid = value


    def to_alipay_dict(self):
        params = dict()
        if self.device_id:
            if hasattr(self.device_id, 'to_alipay_dict'):
                params['device_id'] = self.device_id.to_alipay_dict()
            else:
                params['device_id'] = self.device_id
        if self.isv_pid:
            if hasattr(self.isv_pid, 'to_alipay_dict'):
                params['isv_pid'] = self.isv_pid.to_alipay_dict()
            else:
                params['isv_pid'] = self.isv_pid
        if self.isv_tid:
            if hasattr(self.isv_tid, 'to_alipay_dict'):
                params['isv_tid'] = self.isv_tid.to_alipay_dict()
            else:
                params['isv_tid'] = self.isv_tid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMsaasMediarecogMmtcaftscvDeviceBindModel()
        if 'device_id' in d:
            o.device_id = d['device_id']
        if 'isv_pid' in d:
            o.isv_pid = d['isv_pid']
        if 'isv_tid' in d:
            o.isv_tid = d['isv_tid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenMiniMembersHuobanCreateModel(object):

    def __init__(self):
        self._domain_account = None
        self._login_id = None
        self._operate_app_id = None
        self._type = None

    @property
    def domain_account(self):
        return self._domain_account

    @domain_account.setter
    def domain_account(self, value):
        self._domain_account = value
    @property
    def login_id(self):
        return self._login_id

    @login_id.setter
    def login_id(self, value):
        self._login_id = value
    @property
    def operate_app_id(self):
        return self._operate_app_id

    @operate_app_id.setter
    def operate_app_id(self, value):
        self._operate_app_id = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.domain_account:
            if hasattr(self.domain_account, 'to_alipay_dict'):
                params['domain_account'] = self.domain_account.to_alipay_dict()
            else:
                params['domain_account'] = self.domain_account
        if self.login_id:
            if hasattr(self.login_id, 'to_alipay_dict'):
                params['login_id'] = self.login_id.to_alipay_dict()
            else:
                params['login_id'] = self.login_id
        if self.operate_app_id:
            if hasattr(self.operate_app_id, 'to_alipay_dict'):
                params['operate_app_id'] = self.operate_app_id.to_alipay_dict()
            else:
                params['operate_app_id'] = self.operate_app_id
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniMembersHuobanCreateModel()
        if 'domain_account' in d:
            o.domain_account = d['domain_account']
        if 'login_id' in d:
            o.login_id = d['login_id']
        if 'operate_app_id' in d:
            o.operate_app_id = d['operate_app_id']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceEducateTuitioncodeMonitorCreateModel(object):

    def __init__(self):
        self._bank_type = None
        self._login_account = None
        self._out_apply_id = None
        self._parent_no = None

    @property
    def bank_type(self):
        return self._bank_type

    @bank_type.setter
    def bank_type(self, value):
        self._bank_type = value
    @property
    def login_account(self):
        return self._login_account

    @login_account.setter
    def login_account(self, value):
        self._login_account = value
    @property
    def out_apply_id(self):
        return self._out_apply_id

    @out_apply_id.setter
    def out_apply_id(self, value):
        self._out_apply_id = value
    @property
    def parent_no(self):
        return self._parent_no

    @parent_no.setter
    def parent_no(self, value):
        self._parent_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.bank_type:
            if hasattr(self.bank_type, 'to_alipay_dict'):
                params['bank_type'] = self.bank_type.to_alipay_dict()
            else:
                params['bank_type'] = self.bank_type
        if self.login_account:
            if hasattr(self.login_account, 'to_alipay_dict'):
                params['login_account'] = self.login_account.to_alipay_dict()
            else:
                params['login_account'] = self.login_account
        if self.out_apply_id:
            if hasattr(self.out_apply_id, 'to_alipay_dict'):
                params['out_apply_id'] = self.out_apply_id.to_alipay_dict()
            else:
                params['out_apply_id'] = self.out_apply_id
        if self.parent_no:
            if hasattr(self.parent_no, 'to_alipay_dict'):
                params['parent_no'] = self.parent_no.to_alipay_dict()
            else:
                params['parent_no'] = self.parent_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceEducateTuitioncodeMonitorCreateModel()
        if 'bank_type' in d:
            o.bank_type = d['bank_type']
        if 'login_account' in d:
            o.login_account = d['login_account']
        if 'out_apply_id' in d:
            o.out_apply_id = d['out_apply_id']
        if 'parent_no' in d:
            o.parent_no = d['parent_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayAssetPointPointprodBudgetlibCreateModel(object):

    def __init__(self):
        self._amount = None
        self._budget_name = None
        self._contract_pid = None
        self._end_time = None
        self._fund_source = None
        self._memo = None
        self._operate_channel = None
        self._operator = None
        self._order_no = None
        self._point_lib_id = None
        self._start_time = None
        self._use_settle_tool = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def budget_name(self):
        return self._budget_name

    @budget_name.setter
    def budget_name(self, value):
        self._budget_name = value
    @property
    def contract_pid(self):
        return self._contract_pid

    @contract_pid.setter
    def contract_pid(self, value):
        self._contract_pid = value
    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def fund_source(self):
        return self._fund_source

    @fund_source.setter
    def fund_source(self, value):
        self._fund_source = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def operate_channel(self):
        return self._operate_channel

    @operate_channel.setter
    def operate_channel(self, value):
        self._operate_channel = value
    @property
    def operator(self):
        return self._operator

    @operator.setter
    def operator(self, value):
        self._operator = value
    @property
    def order_no(self):
        return self._order_no

    @order_no.setter
    def order_no(self, value):
        self._order_no = value
    @property
    def point_lib_id(self):
        return self._point_lib_id

    @point_lib_id.setter
    def point_lib_id(self, value):
        self._point_lib_id = value
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value
    @property
    def use_settle_tool(self):
        return self._use_settle_tool

    @use_settle_tool.setter
    def use_settle_tool(self, value):
        self._use_settle_tool = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.budget_name:
            if hasattr(self.budget_name, 'to_alipay_dict'):
                params['budget_name'] = self.budget_name.to_alipay_dict()
            else:
                params['budget_name'] = self.budget_name
        if self.contract_pid:
            if hasattr(self.contract_pid, 'to_alipay_dict'):
                params['contract_pid'] = self.contract_pid.to_alipay_dict()
            else:
                params['contract_pid'] = self.contract_pid
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.fund_source:
            if hasattr(self.fund_source, 'to_alipay_dict'):
                params['fund_source'] = self.fund_source.to_alipay_dict()
            else:
                params['fund_source'] = self.fund_source
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.operate_channel:
            if hasattr(self.operate_channel, 'to_alipay_dict'):
                params['operate_channel'] = self.operate_channel.to_alipay_dict()
            else:
                params['operate_channel'] = self.operate_channel
        if self.operator:
            if hasattr(self.operator, 'to_alipay_dict'):
                params['operator'] = self.operator.to_alipay_dict()
            else:
                params['operator'] = self.operator
        if self.order_no:
            if hasattr(self.order_no, 'to_alipay_dict'):
                params['order_no'] = self.order_no.to_alipay_dict()
            else:
                params['order_no'] = self.order_no
        if self.point_lib_id:
            if hasattr(self.point_lib_id, 'to_alipay_dict'):
                params['point_lib_id'] = self.point_lib_id.to_alipay_dict()
            else:
                params['point_lib_id'] = self.point_lib_id
        if self.start_time:
            if hasattr(self.start_time, 'to_alipay_dict'):
                params['start_time'] = self.start_time.to_alipay_dict()
            else:
                params['start_time'] = self.start_time
        if self.use_settle_tool:
            if hasattr(self.use_settle_tool, 'to_alipay_dict'):
                params['use_settle_tool'] = self.use_settle_tool.to_alipay_dict()
            else:
                params['use_settle_tool'] = self.use_settle_tool
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayAssetPointPointprodBudgetlibCreateModel()
        if 'amount' in d:
            o.amount = d['amount']
        if 'budget_name' in d:
            o.budget_name = d['budget_name']
        if 'contract_pid' in d:
            o.contract_pid = d['contract_pid']
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'fund_source' in d:
            o.fund_source = d['fund_source']
        if 'memo' in d:
            o.memo = d['memo']
        if 'operate_channel' in d:
            o.operate_channel = d['operate_channel']
        if 'operator' in d:
            o.operator = d['operator']
        if 'order_no' in d:
            o.order_no = d['order_no']
        if 'point_lib_id' in d:
            o.point_lib_id = d['point_lib_id']
        if 'start_time' in d:
            o.start_time = d['start_time']
        if 'use_settle_tool' in d:
            o.use_settle_tool = d['use_settle_tool']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZhimaCreditEpDataapiMigrationQueryModel(object):

    def __init__(self):
        self._api_method = None
        self._api_name = None
        self._api_params = None

    @property
    def api_method(self):
        return self._api_method

    @api_method.setter
    def api_method(self, value):
        self._api_method = value
    @property
    def api_name(self):
        return self._api_name

    @api_name.setter
    def api_name(self, value):
        self._api_name = value
    @property
    def api_params(self):
        return self._api_params

    @api_params.setter
    def api_params(self, value):
        self._api_params = value


    def to_alipay_dict(self):
        params = dict()
        if self.api_method:
            if hasattr(self.api_method, 'to_alipay_dict'):
                params['api_method'] = self.api_method.to_alipay_dict()
            else:
                params['api_method'] = self.api_method
        if self.api_name:
            if hasattr(self.api_name, 'to_alipay_dict'):
                params['api_name'] = self.api_name.to_alipay_dict()
            else:
                params['api_name'] = self.api_name
        if self.api_params:
            if hasattr(self.api_params, 'to_alipay_dict'):
                params['api_params'] = self.api_params.to_alipay_dict()
            else:
                params['api_params'] = self.api_params
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaCreditEpDataapiMigrationQueryModel()
        if 'api_method' in d:
            o.api_method = d['api_method']
        if 'api_name' in d:
            o.api_name = d['api_name']
        if 'api_params' in d:
            o.api_params = d['api_params']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.RecomPlan import RecomPlan
from alipay.aop.api.domain.ProdResource import ProdResource
from alipay.aop.api.domain.ProdResource import ProdResource


class RecomProduct(object):

    def __init__(self):
        self._base_premium = None
        self._biz_data = None
        self._company_id = None
        self._company_name = None
        self._company_seller_id = None
        self._company_seller_nick = None
        self._company_service_phone = None
        self._csu_no = None
        self._max_quan = None
        self._name = None
        self._plans = None
        self._premium = None
        self._prod_no = None
        self._recom_flow_no = None
        self._resource_list = None
        self._resources = None
        self._restriction_type = None
        self._sum_insured = None
        self._type = None

    @property
    def base_premium(self):
        return self._base_premium

    @base_premium.setter
    def base_premium(self, value):
        self._base_premium = value
    @property
    def biz_data(self):
        return self._biz_data

    @biz_data.setter
    def biz_data(self, value):
        self._biz_data = value
    @property
    def company_id(self):
        return self._company_id

    @company_id.setter
    def company_id(self, value):
        self._company_id = value
    @property
    def company_name(self):
        return self._company_name

    @company_name.setter
    def company_name(self, value):
        self._company_name = value
    @property
    def company_seller_id(self):
        return self._company_seller_id

    @company_seller_id.setter
    def company_seller_id(self, value):
        self._company_seller_id = value
    @property
    def company_seller_nick(self):
        return self._company_seller_nick

    @company_seller_nick.setter
    def company_seller_nick(self, value):
        self._company_seller_nick = value
    @property
    def company_service_phone(self):
        return self._company_service_phone

    @company_service_phone.setter
    def company_service_phone(self, value):
        self._company_service_phone = value
    @property
    def csu_no(self):
        return self._csu_no

    @csu_no.setter
    def csu_no(self, value):
        self._csu_no = value
    @property
    def max_quan(self):
        return self._max_quan

    @max_quan.setter
    def max_quan(self, value):
        self._max_quan = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def plans(self):
        return self._plans

    @plans.setter
    def plans(self, value):
        if isinstance(value, RecomPlan):
            self._plans = value
        else:
            self._plans = RecomPlan.from_alipay_dict(value)
    @property
    def premium(self):
        return self._premium

    @premium.setter
    def premium(self, value):
        self._premium = value
    @property
    def prod_no(self):
        return self._prod_no

    @prod_no.setter
    def prod_no(self, value):
        self._prod_no = value
    @property
    def recom_flow_no(self):
        return self._recom_flow_no

    @recom_flow_no.setter
    def recom_flow_no(self, value):
        self._recom_flow_no = value
    @property
    def resource_list(self):
        return self._resource_list

    @resource_list.setter
    def resource_list(self, value):
        if isinstance(value, list):
            self._resource_list = list()
            for i in value:
                if isinstance(i, ProdResource):
                    self._resource_list.append(i)
                else:
                    self._resource_list.append(ProdResource.from_alipay_dict(i))
    @property
    def resources(self):
        return self._resources

    @resources.setter
    def resources(self, value):
        if isinstance(value, ProdResource):
            self._resources = value
        else:
            self._resources = ProdResource.from_alipay_dict(value)
    @property
    def restriction_type(self):
        return self._restriction_type

    @restriction_type.setter
    def restriction_type(self, value):
        self._restriction_type = value
    @property
    def sum_insured(self):
        return self._sum_insured

    @sum_insured.setter
    def sum_insured(self, value):
        self._sum_insured = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.base_premium:
            if hasattr(self.base_premium, 'to_alipay_dict'):
                params['base_premium'] = self.base_premium.to_alipay_dict()
            else:
                params['base_premium'] = self.base_premium
        if self.biz_data:
            if hasattr(self.biz_data, 'to_alipay_dict'):
                params['biz_data'] = self.biz_data.to_alipay_dict()
            else:
                params['biz_data'] = self.biz_data
        if self.company_id:
            if hasattr(self.company_id, 'to_alipay_dict'):
                params['company_id'] = self.company_id.to_alipay_dict()
            else:
                params['company_id'] = self.company_id
        if self.company_name:
            if hasattr(self.company_name, 'to_alipay_dict'):
                params['company_name'] = self.company_name.to_alipay_dict()
            else:
                params['company_name'] = self.company_name
        if self.company_seller_id:
            if hasattr(self.company_seller_id, 'to_alipay_dict'):
                params['company_seller_id'] = self.company_seller_id.to_alipay_dict()
            else:
                params['company_seller_id'] = self.company_seller_id
        if self.company_seller_nick:
            if hasattr(self.company_seller_nick, 'to_alipay_dict'):
                params['company_seller_nick'] = self.company_seller_nick.to_alipay_dict()
            else:
                params['company_seller_nick'] = self.company_seller_nick
        if self.company_service_phone:
            if hasattr(self.company_service_phone, 'to_alipay_dict'):
                params['company_service_phone'] = self.company_service_phone.to_alipay_dict()
            else:
                params['company_service_phone'] = self.company_service_phone
        if self.csu_no:
            if hasattr(self.csu_no, 'to_alipay_dict'):
                params['csu_no'] = self.csu_no.to_alipay_dict()
            else:
                params['csu_no'] = self.csu_no
        if self.max_quan:
            if hasattr(self.max_quan, 'to_alipay_dict'):
                params['max_quan'] = self.max_quan.to_alipay_dict()
            else:
                params['max_quan'] = self.max_quan
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.plans:
            if hasattr(self.plans, 'to_alipay_dict'):
                params['plans'] = self.plans.to_alipay_dict()
            else:
                params['plans'] = self.plans
        if self.premium:
            if hasattr(self.premium, 'to_alipay_dict'):
                params['premium'] = self.premium.to_alipay_dict()
            else:
                params['premium'] = self.premium
        if self.prod_no:
            if hasattr(self.prod_no, 'to_alipay_dict'):
                params['prod_no'] = self.prod_no.to_alipay_dict()
            else:
                params['prod_no'] = self.prod_no
        if self.recom_flow_no:
            if hasattr(self.recom_flow_no, 'to_alipay_dict'):
                params['recom_flow_no'] = self.recom_flow_no.to_alipay_dict()
            else:
                params['recom_flow_no'] = self.recom_flow_no
        if self.resource_list:
            if isinstance(self.resource_list, list):
                for i in range(0, len(self.resource_list)):
                    element = self.resource_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.resource_list[i] = element.to_alipay_dict()
            if hasattr(self.resource_list, 'to_alipay_dict'):
                params['resource_list'] = self.resource_list.to_alipay_dict()
            else:
                params['resource_list'] = self.resource_list
        if self.resources:
            if hasattr(self.resources, 'to_alipay_dict'):
                params['resources'] = self.resources.to_alipay_dict()
            else:
                params['resources'] = self.resources
        if self.restriction_type:
            if hasattr(self.restriction_type, 'to_alipay_dict'):
                params['restriction_type'] = self.restriction_type.to_alipay_dict()
            else:
                params['restriction_type'] = self.restriction_type
        if self.sum_insured:
            if hasattr(self.sum_insured, 'to_alipay_dict'):
                params['sum_insured'] = self.sum_insured.to_alipay_dict()
            else:
                params['sum_insured'] = self.sum_insured
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = RecomProduct()
        if 'base_premium' in d:
            o.base_premium = d['base_premium']
        if 'biz_data' in d:
            o.biz_data = d['biz_data']
        if 'company_id' in d:
            o.company_id = d['company_id']
        if 'company_name' in d:
            o.company_name = d['company_name']
        if 'company_seller_id' in d:
            o.company_seller_id = d['company_seller_id']
        if 'company_seller_nick' in d:
            o.company_seller_nick = d['company_seller_nick']
        if 'company_service_phone' in d:
            o.company_service_phone = d['company_service_phone']
        if 'csu_no' in d:
            o.csu_no = d['csu_no']
        if 'max_quan' in d:
            o.max_quan = d['max_quan']
        if 'name' in d:
            o.name = d['name']
        if 'plans' in d:
            o.plans = d['plans']
        if 'premium' in d:
            o.premium = d['premium']
        if 'prod_no' in d:
            o.prod_no = d['prod_no']
        if 'recom_flow_no' in d:
            o.recom_flow_no = d['recom_flow_no']
        if 'resource_list' in d:
            o.resource_list = d['resource_list']
        if 'resources' in d:
            o.resources = d['resources']
        if 'restriction_type' in d:
            o.restriction_type = d['restriction_type']
        if 'sum_insured' in d:
            o.sum_insured = d['sum_insured']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayIserviceCcmRoleCreateModel(object):

    def __init__(self):
        self._ccs_instance_id = None
        self._creator_id = None
        self._description = None
        self._function_ids = None
        self._name = None

    @property
    def ccs_instance_id(self):
        return self._ccs_instance_id

    @ccs_instance_id.setter
    def ccs_instance_id(self, value):
        self._ccs_instance_id = value
    @property
    def creator_id(self):
        return self._creator_id

    @creator_id.setter
    def creator_id(self, value):
        self._creator_id = value
    @property
    def description(self):
        return self._description

    @description.setter
    def description(self, value):
        self._description = value
    @property
    def function_ids(self):
        return self._function_ids

    @function_ids.setter
    def function_ids(self, value):
        if isinstance(value, list):
            self._function_ids = list()
            for i in value:
                self._function_ids.append(i)
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value


    def to_alipay_dict(self):
        params = dict()
        if self.ccs_instance_id:
            if hasattr(self.ccs_instance_id, 'to_alipay_dict'):
                params['ccs_instance_id'] = self.ccs_instance_id.to_alipay_dict()
            else:
                params['ccs_instance_id'] = self.ccs_instance_id
        if self.creator_id:
            if hasattr(self.creator_id, 'to_alipay_dict'):
                params['creator_id'] = self.creator_id.to_alipay_dict()
            else:
                params['creator_id'] = self.creator_id
        if self.description:
            if hasattr(self.description, 'to_alipay_dict'):
                params['description'] = self.description.to_alipay_dict()
            else:
                params['description'] = self.description
        if self.function_ids:
            if isinstance(self.function_ids, list):
                for i in range(0, len(self.function_ids)):
                    element = self.function_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.function_ids[i] = element.to_alipay_dict()
            if hasattr(self.function_ids, 'to_alipay_dict'):
                params['function_ids'] = self.function_ids.to_alipay_dict()
            else:
                params['function_ids'] = self.function_ids
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayIserviceCcmRoleCreateModel()
        if 'ccs_instance_id' in d:
            o.ccs_instance_id = d['ccs_instance_id']
        if 'creator_id' in d:
            o.creator_id = d['creator_id']
        if 'description' in d:
            o.description = d['description']
        if 'function_ids' in d:
            o.function_ids = d['function_ids']
        if 'name' in d:
            o.name = d['name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SsdataDataserviceRiskAntifraudscoreQueryModel(object):

    def __init__(self):
        self._address = None
        self._bank_card = None
        self._cert_no = None
        self._cert_type = None
        self._email = None
        self._imei = None
        self._ip = None
        self._mac = None
        self._mobile = None
        self._name = None
        self._partner_id = None
        self._wifimac = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def bank_card(self):
        return self._bank_card

    @bank_card.setter
    def bank_card(self, value):
        self._bank_card = value
    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def cert_type(self):
        return self._cert_type

    @cert_type.setter
    def cert_type(self, value):
        self._cert_type = value
    @property
    def email(self):
        return self._email

    @email.setter
    def email(self, value):
        self._email = value
    @property
    def imei(self):
        return self._imei

    @imei.setter
    def imei(self, value):
        self._imei = value
    @property
    def ip(self):
        return self._ip

    @ip.setter
    def ip(self, value):
        self._ip = value
    @property
    def mac(self):
        return self._mac

    @mac.setter
    def mac(self, value):
        self._mac = value
    @property
    def mobile(self):
        return self._mobile

    @mobile.setter
    def mobile(self, value):
        self._mobile = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def wifimac(self):
        return self._wifimac

    @wifimac.setter
    def wifimac(self, value):
        self._wifimac = value


    def to_alipay_dict(self):
        params = dict()
        if self.address:
            if hasattr(self.address, 'to_alipay_dict'):
                params['address'] = self.address.to_alipay_dict()
            else:
                params['address'] = self.address
        if self.bank_card:
            if hasattr(self.bank_card, 'to_alipay_dict'):
                params['bank_card'] = self.bank_card.to_alipay_dict()
            else:
                params['bank_card'] = self.bank_card
        if self.cert_no:
            if hasattr(self.cert_no, 'to_alipay_dict'):
                params['cert_no'] = self.cert_no.to_alipay_dict()
            else:
                params['cert_no'] = self.cert_no
        if self.cert_type:
            if hasattr(self.cert_type, 'to_alipay_dict'):
                params['cert_type'] = self.cert_type.to_alipay_dict()
            else:
                params['cert_type'] = self.cert_type
        if self.email:
            if hasattr(self.email, 'to_alipay_dict'):
                params['email'] = self.email.to_alipay_dict()
            else:
                params['email'] = self.email
        if self.imei:
            if hasattr(self.imei, 'to_alipay_dict'):
                params['imei'] = self.imei.to_alipay_dict()
            else:
                params['imei'] = self.imei
        if self.ip:
            if hasattr(self.ip, 'to_alipay_dict'):
                params['ip'] = self.ip.to_alipay_dict()
            else:
                params['ip'] = self.ip
        if self.mac:
            if hasattr(self.mac, 'to_alipay_dict'):
                params['mac'] = self.mac.to_alipay_dict()
            else:
                params['mac'] = self.mac
        if self.mobile:
            if hasattr(self.mobile, 'to_alipay_dict'):
                params['mobile'] = self.mobile.to_alipay_dict()
            else:
                params['mobile'] = self.mobile
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = self.partner_id.to_alipay_dict()
            else:
                params['partner_id'] = self.partner_id
        if self.wifimac:
            if hasattr(self.wifimac, 'to_alipay_dict'):
                params['wifimac'] = self.wifimac.to_alipay_dict()
            else:
                params['wifimac'] = self.wifimac
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SsdataDataserviceRiskAntifraudscoreQueryModel()
        if 'address' in d:
            o.address = d['address']
        if 'bank_card' in d:
            o.bank_card = d['bank_card']
        if 'cert_no' in d:
            o.cert_no = d['cert_no']
        if 'cert_type' in d:
            o.cert_type = d['cert_type']
        if 'email' in d:
            o.email = d['email']
        if 'imei' in d:
            o.imei = d['imei']
        if 'ip' in d:
            o.ip = d['ip']
        if 'mac' in d:
            o.mac = d['mac']
        if 'mobile' in d:
            o.mobile = d['mobile']
        if 'name' in d:
            o.name = d['name']
        if 'partner_id' in d:
            o.partner_id = d['partner_id']
        if 'wifimac' in d:
            o.wifimac = d['wifimac']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class InsHealthSendFlowResult(object):

    def __init__(self):
        self._biz_type = None
        self._entrance = None
        self._offer_time = None
        self._out_biz_no = None
        self._product_group_biz_type = None
        self._product_sum_insured = None
        self._source = None
        self._status = None
        self._user_id = None

    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def entrance(self):
        return self._entrance

    @entrance.setter
    def entrance(self, value):
        self._entrance = value
    @property
    def offer_time(self):
        return self._offer_time

    @offer_time.setter
    def offer_time(self, value):
        self._offer_time = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def product_group_biz_type(self):
        return self._product_group_biz_type

    @product_group_biz_type.setter
    def product_group_biz_type(self, value):
        self._product_group_biz_type = value
    @property
    def product_sum_insured(self):
        return self._product_sum_insured

    @product_sum_insured.setter
    def product_sum_insured(self, value):
        self._product_sum_insured = value
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.entrance:
            if hasattr(self.entrance, 'to_alipay_dict'):
                params['entrance'] = self.entrance.to_alipay_dict()
            else:
                params['entrance'] = self.entrance
        if self.offer_time:
            if hasattr(self.offer_time, 'to_alipay_dict'):
                params['offer_time'] = self.offer_time.to_alipay_dict()
            else:
                params['offer_time'] = self.offer_time
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.product_group_biz_type:
            if hasattr(self.product_group_biz_type, 'to_alipay_dict'):
                params['product_group_biz_type'] = self.product_group_biz_type.to_alipay_dict()
            else:
                params['product_group_biz_type'] = self.product_group_biz_type
        if self.product_sum_insured:
            if hasattr(self.product_sum_insured, 'to_alipay_dict'):
                params['product_sum_insured'] = self.product_sum_insured.to_alipay_dict()
            else:
                params['product_sum_insured'] = self.product_sum_insured
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InsHealthSendFlowResult()
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'entrance' in d:
            o.entrance = d['entrance']
        if 'offer_time' in d:
            o.offer_time = d['offer_time']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'product_group_biz_type' in d:
            o.product_group_biz_type = d['product_group_biz_type']
        if 'product_sum_insured' in d:
            o.product_sum_insured = d['product_sum_insured']
        if 'source' in d:
            o.source = d['source']
        if 'status' in d:
            o.status = d['status']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayUserAuthSecondpartyTokenVerifyResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserAuthSecondpartyTokenVerifyResponse, self).__init__()
        self._tb_user_id = None

    @property
    def tb_user_id(self):
        return self._tb_user_id

    @tb_user_id.setter
    def tb_user_id(self, value):
        self._tb_user_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayUserAuthSecondpartyTokenVerifyResponse, self).parse_response_content(response_content)
        if 'tb_user_id' in response:
            self.tb_user_id = response['tb_user_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ObjectKeyWord(object):

    def __init__(self):
        self._category = None
        self._key_word = None
        self._score = None

    @property
    def category(self):
        return self._category

    @category.setter
    def category(self, value):
        self._category = value
    @property
    def key_word(self):
        return self._key_word

    @key_word.setter
    def key_word(self, value):
        self._key_word = value
    @property
    def score(self):
        return self._score

    @score.setter
    def score(self, value):
        self._score = value


    def to_alipay_dict(self):
        params = dict()
        if self.category:
            if hasattr(self.category, 'to_alipay_dict'):
                params['category'] = self.category.to_alipay_dict()
            else:
                params['category'] = self.category
        if self.key_word:
            if hasattr(self.key_word, 'to_alipay_dict'):
                params['key_word'] = self.key_word.to_alipay_dict()
            else:
                params['key_word'] = self.key_word
        if self.score:
            if hasattr(self.score, 'to_alipay_dict'):
                params['score'] = self.score.to_alipay_dict()
            else:
                params['score'] = self.score
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ObjectKeyWord()
        if 'category' in d:
            o.category = d['category']
        if 'key_word' in d:
            o.key_word = d['key_word']
        if 'score' in d:
            o.score = d['score']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMarketingCampaignDiscountWhitelistQueryModel(object):

    def __init__(self):
        self._camp_id = None

    @property
    def camp_id(self):
        return self._camp_id

    @camp_id.setter
    def camp_id(self, value):
        self._camp_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.camp_id:
            if hasattr(self.camp_id, 'to_alipay_dict'):
                params['camp_id'] = self.camp_id.to_alipay_dict()
            else:
                params['camp_id'] = self.camp_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingCampaignDiscountWhitelistQueryModel()
        if 'camp_id' in d:
            o.camp_id = d['camp_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipaySocialBaseContentlibStandardvideoauditSendResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySocialBaseContentlibStandardvideoauditSendResponse, self).__init__()
        self._result_msg = None

    @property
    def result_msg(self):
        return self._result_msg

    @result_msg.setter
    def result_msg(self, value):
        self._result_msg = value

    def parse_response_content(self, response_content):
        response = super(AlipaySocialBaseContentlibStandardvideoauditSendResponse, self).parse_response_content(response_content)
        if 'result_msg' in response:
            self.result_msg = response['result_msg']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KbOrderFundsVoucherModel(object):

    def __init__(self):
        self._account = None
        self._amount = None
        self._funds_voucher_no = None
        self._gmt_create = None
        self._shop_id = None
        self._store_id = None
        self._trans_type = None

    @property
    def account(self):
        return self._account

    @account.setter
    def account(self, value):
        self._account = value
    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def funds_voucher_no(self):
        return self._funds_voucher_no

    @funds_voucher_no.setter
    def funds_voucher_no(self, value):
        self._funds_voucher_no = value
    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def store_id(self):
        return self._store_id

    @store_id.setter
    def store_id(self, value):
        self._store_id = value
    @property
    def trans_type(self):
        return self._trans_type

    @trans_type.setter
    def trans_type(self, value):
        self._trans_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.account:
            if hasattr(self.account, 'to_alipay_dict'):
                params['account'] = self.account.to_alipay_dict()
            else:
                params['account'] = self.account
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.funds_voucher_no:
            if hasattr(self.funds_voucher_no, 'to_alipay_dict'):
                params['funds_voucher_no'] = self.funds_voucher_no.to_alipay_dict()
            else:
                params['funds_voucher_no'] = self.funds_voucher_no
        if self.gmt_create:
            if hasattr(self.gmt_create, 'to_alipay_dict'):
                params['gmt_create'] = self.gmt_create.to_alipay_dict()
            else:
                params['gmt_create'] = self.gmt_create
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.store_id:
            if hasattr(self.store_id, 'to_alipay_dict'):
                params['store_id'] = self.store_id.to_alipay_dict()
            else:
                params['store_id'] = self.store_id
        if self.trans_type:
            if hasattr(self.trans_type, 'to_alipay_dict'):
                params['trans_type'] = self.trans_type.to_alipay_dict()
            else:
                params['trans_type'] = self.trans_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KbOrderFundsVoucherModel()
        if 'account' in d:
            o.account = d['account']
        if 'amount' in d:
            o.amount = d['amount']
        if 'funds_voucher_no' in d:
            o.funds_voucher_no = d['funds_voucher_no']
        if 'gmt_create' in d:
            o.gmt_create = d['gmt_create']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'store_id' in d:
            o.store_id = d['store_id']
        if 'trans_type' in d:
            o.trans_type = d['trans_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayUserAgreementExecutionplanModifyResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserAgreementExecutionplanModifyResponse, self).__init__()
        self._agreement_no = None
        self._deduct_time = None

    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def deduct_time(self):
        return self._deduct_time

    @deduct_time.setter
    def deduct_time(self, value):
        self._deduct_time = value

    def parse_response_content(self, response_content):
        response = super(AlipayUserAgreementExecutionplanModifyResponse, self).parse_response_content(response_content)
        if 'agreement_no' in response:
            self.agreement_no = response['agreement_no']
        if 'deduct_time' in response:
            self.deduct_time = response['deduct_time']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ScenicFaceInfo import ScenicFaceInfo


class AlipayCommerceEducateFacefeatureDeleteModel(object):

    def __init__(self):
        self._biz_code = None
        self._biz_id = None
        self._ext_info = None
        self._group_id = None
        self._inst_id = None
        self._isv_name = None
        self._scenic_face_info = None

    @property
    def biz_code(self):
        return self._biz_code

    @biz_code.setter
    def biz_code(self, value):
        self._biz_code = value
    @property
    def biz_id(self):
        return self._biz_id

    @biz_id.setter
    def biz_id(self, value):
        self._biz_id = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def group_id(self):
        return self._group_id

    @group_id.setter
    def group_id(self, value):
        self._group_id = value
    @property
    def inst_id(self):
        return self._inst_id

    @inst_id.setter
    def inst_id(self, value):
        self._inst_id = value
    @property
    def isv_name(self):
        return self._isv_name

    @isv_name.setter
    def isv_name(self, value):
        self._isv_name = value
    @property
    def scenic_face_info(self):
        return self._scenic_face_info

    @scenic_face_info.setter
    def scenic_face_info(self, value):
        if isinstance(value, list):
            self._scenic_face_info = list()
            for i in value:
                if isinstance(i, ScenicFaceInfo):
                    self._scenic_face_info.append(i)
                else:
                    self._scenic_face_info.append(ScenicFaceInfo.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.biz_code:
            if hasattr(self.biz_code, 'to_alipay_dict'):
                params['biz_code'] = self.biz_code.to_alipay_dict()
            else:
                params['biz_code'] = self.biz_code
        if self.biz_id:
            if hasattr(self.biz_id, 'to_alipay_dict'):
                params['biz_id'] = self.biz_id.to_alipay_dict()
            else:
                params['biz_id'] = self.biz_id
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.group_id:
            if hasattr(self.group_id, 'to_alipay_dict'):
                params['group_id'] = self.group_id.to_alipay_dict()
            else:
                params['group_id'] = self.group_id
        if self.inst_id:
            if hasattr(self.inst_id, 'to_alipay_dict'):
                params['inst_id'] = self.inst_id.to_alipay_dict()
            else:
                params['inst_id'] = self.inst_id
        if self.isv_name:
            if hasattr(self.isv_name, 'to_alipay_dict'):
                params['isv_name'] = self.isv_name.to_alipay_dict()
            else:
                params['isv_name'] = self.isv_name
        if self.scenic_face_info:
            if isinstance(self.scenic_face_info, list):
                for i in range(0, len(self.scenic_face_info)):
                    element = self.scenic_face_info[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.scenic_face_info[i] = element.to_alipay_dict()
            if hasattr(self.scenic_face_info, 'to_alipay_dict'):
                params['scenic_face_info'] = self.scenic_face_info.to_alipay_dict()
            else:
                params['scenic_face_info'] = self.scenic_face_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceEducateFacefeatureDeleteModel()
        if 'biz_code' in d:
            o.biz_code = d['biz_code']
        if 'biz_id' in d:
            o.biz_id = d['biz_id']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'group_id' in d:
            o.group_id = d['group_id']
        if 'inst_id' in d:
            o.inst_id = d['inst_id']
        if 'isv_name' in d:
            o.isv_name = d['isv_name']
        if 'scenic_face_info' in d:
            o.scenic_face_info = d['scenic_face_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.CompanyOverviewInfo import CompanyOverviewInfo


class ZhimaCreditEpDossierCompanyoverviewQueryResponse(AlipayResponse):

    def __init__(self):
        super(ZhimaCreditEpDossierCompanyoverviewQueryResponse, self).__init__()
        self._company_overview_info = None

    @property
    def company_overview_info(self):
        return self._company_overview_info

    @company_overview_info.setter
    def company_overview_info(self, value):
        if isinstance(value, CompanyOverviewInfo):
            self._company_overview_info = value
        else:
            self._company_overview_info = CompanyOverviewInfo.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(ZhimaCreditEpDossierCompanyoverviewQueryResponse, self).parse_response_content(response_content)
        if 'company_overview_info' in response:
            self.company_overview_info = response['company_overview_info']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class ZhimaMerchantOrderCreditCreateResponse(AlipayResponse):

    def __init__(self):
        super(ZhimaMerchantOrderCreditCreateResponse, self).__init__()
        self._error_code = None
        self._error_msg = None
        self._order_create_time = None
        self._order_status = None
        self._out_order_no = None
        self._page_type = None
        self._success = None
        self._zm_order_no = None

    @property
    def error_code(self):
        return self._error_code

    @error_code.setter
    def error_code(self, value):
        self._error_code = value
    @property
    def error_msg(self):
        return self._error_msg

    @error_msg.setter
    def error_msg(self, value):
        self._error_msg = value
    @property
    def order_create_time(self):
        return self._order_create_time

    @order_create_time.setter
    def order_create_time(self, value):
        self._order_create_time = value
    @property
    def order_status(self):
        return self._order_status

    @order_status.setter
    def order_status(self, value):
        self._order_status = value
    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def page_type(self):
        return self._page_type

    @page_type.setter
    def page_type(self, value):
        self._page_type = value
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value
    @property
    def zm_order_no(self):
        return self._zm_order_no

    @zm_order_no.setter
    def zm_order_no(self, value):
        self._zm_order_no = value

    def parse_response_content(self, response_content):
        response = super(ZhimaMerchantOrderCreditCreateResponse, self).parse_response_content(response_content)
        if 'error_code' in response:
            self.error_code = response['error_code']
        if 'error_msg' in response:
            self.error_msg = response['error_msg']
        if 'order_create_time' in response:
            self.order_create_time = response['order_create_time']
        if 'order_status' in response:
            self.order_status = response['order_status']
        if 'out_order_no' in response:
            self.out_order_no = response['out_order_no']
        if 'page_type' in response:
            self.page_type = response['page_type']
        if 'success' in response:
            self.success = response['success']
        if 'zm_order_no' in response:
            self.zm_order_no = response['zm_order_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.McardTemplateBenefit import McardTemplateBenefit


class AlipayMarketingCardBenefitCreateModel(object):

    def __init__(self):
        self._mcard_template_benefit = None

    @property
    def mcard_template_benefit(self):
        return self._mcard_template_benefit

    @mcard_template_benefit.setter
    def mcard_template_benefit(self, value):
        if isinstance(value, McardTemplateBenefit):
            self._mcard_template_benefit = value
        else:
            self._mcard_template_benefit = McardTemplateBenefit.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.mcard_template_benefit:
            if hasattr(self.mcard_template_benefit, 'to_alipay_dict'):
                params['mcard_template_benefit'] = self.mcard_template_benefit.to_alipay_dict()
            else:
                params['mcard_template_benefit'] = self.mcard_template_benefit
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingCardBenefitCreateModel()
        if 'mcard_template_benefit' in d:
            o.mcard_template_benefit = d['mcard_template_benefit']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MemberCardTemplateAuxiliaryItem import MemberCardTemplateAuxiliaryItem
from alipay.aop.api.domain.MemberCardTemplateHeaderConfig import MemberCardTemplateHeaderConfig
from alipay.aop.api.domain.MemberCardTemplateOperationItem import MemberCardTemplateOperationItem
from alipay.aop.api.domain.MemberCardTemplateSecondaryItem import MemberCardTemplateSecondaryItem


class MemberCardTemplateConfig(object):

    def __init__(self):
        self._auxiliary_item_list = None
        self._header = None
        self._operation_item_list = None
        self._secondary_item_list = None

    @property
    def auxiliary_item_list(self):
        return self._auxiliary_item_list

    @auxiliary_item_list.setter
    def auxiliary_item_list(self, value):
        if isinstance(value, list):
            self._auxiliary_item_list = list()
            for i in value:
                if isinstance(i, MemberCardTemplateAuxiliaryItem):
                    self._auxiliary_item_list.append(i)
                else:
                    self._auxiliary_item_list.append(MemberCardTemplateAuxiliaryItem.from_alipay_dict(i))
    @property
    def header(self):
        return self._header

    @header.setter
    def header(self, value):
        if isinstance(value, MemberCardTemplateHeaderConfig):
            self._header = value
        else:
            self._header = MemberCardTemplateHeaderConfig.from_alipay_dict(value)
    @property
    def operation_item_list(self):
        return self._operation_item_list

    @operation_item_list.setter
    def operation_item_list(self, value):
        if isinstance(value, list):
            self._operation_item_list = list()
            for i in value:
                if isinstance(i, MemberCardTemplateOperationItem):
                    self._operation_item_list.append(i)
                else:
                    self._operation_item_list.append(MemberCardTemplateOperationItem.from_alipay_dict(i))
    @property
    def secondary_item_list(self):
        return self._secondary_item_list

    @secondary_item_list.setter
    def secondary_item_list(self, value):
        if isinstance(value, list):
            self._secondary_item_list = list()
            for i in value:
                if isinstance(i, MemberCardTemplateSecondaryItem):
                    self._secondary_item_list.append(i)
                else:
                    self._secondary_item_list.append(MemberCardTemplateSecondaryItem.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.auxiliary_item_list:
            if isinstance(self.auxiliary_item_list, list):
                for i in range(0, len(self.auxiliary_item_list)):
                    element = self.auxiliary_item_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.auxiliary_item_list[i] = element.to_alipay_dict()
            if hasattr(self.auxiliary_item_list, 'to_alipay_dict'):
                params['auxiliary_item_list'] = self.auxiliary_item_list.to_alipay_dict()
            else:
                params['auxiliary_item_list'] = self.auxiliary_item_list
        if self.header:
            if hasattr(self.header, 'to_alipay_dict'):
                params['header'] = self.header.to_alipay_dict()
            else:
                params['header'] = self.header
        if self.operation_item_list:
            if isinstance(self.operation_item_list, list):
                for i in range(0, len(self.operation_item_list)):
                    element = self.operation_item_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.operation_item_list[i] = element.to_alipay_dict()
            if hasattr(self.operation_item_list, 'to_alipay_dict'):
                params['operation_item_list'] = self.operation_item_list.to_alipay_dict()
            else:
                params['operation_item_list'] = self.operation_item_list
        if self.secondary_item_list:
            if isinstance(self.secondary_item_list, list):
                for i in range(0, len(self.secondary_item_list)):
                    element = self.secondary_item_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.secondary_item_list[i] = element.to_alipay_dict()
            if hasattr(self.secondary_item_list, 'to_alipay_dict'):
                params['secondary_item_list'] = self.secondary_item_list.to_alipay_dict()
            else:
                params['secondary_item_list'] = self.secondary_item_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MemberCardTemplateConfig()
        if 'auxiliary_item_list' in d:
            o.auxiliary_item_list = d['auxiliary_item_list']
        if 'header' in d:
            o.header = d['header']
        if 'operation_item_list' in d:
            o.operation_item_list = d['operation_item_list']
        if 'secondary_item_list' in d:
            o.secondary_item_list = d['secondary_item_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class IsvMerchantSalesDetailRequest(object):

    def __init__(self):
        self._coupons_quantity = None
        self._device_detail = None
        self._merchant_pid = None
        self._mini_appid = None
        self._operation_place = None
        self._out_biz_no = None
        self._promotor_pid = None
        self._sales_amount = None
        self._sales_quantity = None
        self._sub_promotor_pid = None
        self._write_off_amount = None
        self._write_off_quantity = None

    @property
    def coupons_quantity(self):
        return self._coupons_quantity

    @coupons_quantity.setter
    def coupons_quantity(self, value):
        self._coupons_quantity = value
    @property
    def device_detail(self):
        return self._device_detail

    @device_detail.setter
    def device_detail(self, value):
        self._device_detail = value
    @property
    def merchant_pid(self):
        return self._merchant_pid

    @merchant_pid.setter
    def merchant_pid(self, value):
        self._merchant_pid = value
    @property
    def mini_appid(self):
        return self._mini_appid

    @mini_appid.setter
    def mini_appid(self, value):
        self._mini_appid = value
    @property
    def operation_place(self):
        return self._operation_place

    @operation_place.setter
    def operation_place(self, value):
        self._operation_place = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def promotor_pid(self):
        return self._promotor_pid

    @promotor_pid.setter
    def promotor_pid(self, value):
        self._promotor_pid = value
    @property
    def sales_amount(self):
        return self._sales_amount

    @sales_amount.setter
    def sales_amount(self, value):
        self._sales_amount = value
    @property
    def sales_quantity(self):
        return self._sales_quantity

    @sales_quantity.setter
    def sales_quantity(self, value):
        self._sales_quantity = value
    @property
    def sub_promotor_pid(self):
        return self._sub_promotor_pid

    @sub_promotor_pid.setter
    def sub_promotor_pid(self, value):
        self._sub_promotor_pid = value
    @property
    def write_off_amount(self):
        return self._write_off_amount

    @write_off_amount.setter
    def write_off_amount(self, value):
        self._write_off_amount = value
    @property
    def write_off_quantity(self):
        return self._write_off_quantity

    @write_off_quantity.setter
    def write_off_quantity(self, value):
        self._write_off_quantity = value


    def to_alipay_dict(self):
        params = dict()
        if self.coupons_quantity:
            if hasattr(self.coupons_quantity, 'to_alipay_dict'):
                params['coupons_quantity'] = self.coupons_quantity.to_alipay_dict()
            else:
                params['coupons_quantity'] = self.coupons_quantity
        if self.device_detail:
            if hasattr(self.device_detail, 'to_alipay_dict'):
                params['device_detail'] = self.device_detail.to_alipay_dict()
            else:
                params['device_detail'] = self.device_detail
        if self.merchant_pid:
            if hasattr(self.merchant_pid, 'to_alipay_dict'):
                params['merchant_pid'] = self.merchant_pid.to_alipay_dict()
            else:
                params['merchant_pid'] = self.merchant_pid
        if self.mini_appid:
            if hasattr(self.mini_appid, 'to_alipay_dict'):
                params['mini_appid'] = self.mini_appid.to_alipay_dict()
            else:
                params['mini_appid'] = self.mini_appid
        if self.operation_place:
            if hasattr(self.operation_place, 'to_alipay_dict'):
                params['operation_place'] = self.operation_place.to_alipay_dict()
            else:
                params['operation_place'] = self.operation_place
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.promotor_pid:
            if hasattr(self.promotor_pid, 'to_alipay_dict'):
                params['promotor_pid'] = self.promotor_pid.to_alipay_dict()
            else:
                params['promotor_pid'] = self.promotor_pid
        if self.sales_amount:
            if hasattr(self.sales_amount, 'to_alipay_dict'):
                params['sales_amount'] = self.sales_amount.to_alipay_dict()
            else:
                params['sales_amount'] = self.sales_amount
        if self.sales_quantity:
            if hasattr(self.sales_quantity, 'to_alipay_dict'):
                params['sales_quantity'] = self.sales_quantity.to_alipay_dict()
            else:
                params['sales_quantity'] = self.sales_quantity
        if self.sub_promotor_pid:
            if hasattr(self.sub_promotor_pid, 'to_alipay_dict'):
                params['sub_promotor_pid'] = self.sub_promotor_pid.to_alipay_dict()
            else:
                params['sub_promotor_pid'] = self.sub_promotor_pid
        if self.write_off_amount:
            if hasattr(self.write_off_amount, 'to_alipay_dict'):
                params['write_off_amount'] = self.write_off_amount.to_alipay_dict()
            else:
                params['write_off_amount'] = self.write_off_amount
        if self.write_off_quantity:
            if hasattr(self.write_off_quantity, 'to_alipay_dict'):
                params['write_off_quantity'] = self.write_off_quantity.to_alipay_dict()
            else:
                params['write_off_quantity'] = self.write_off_quantity
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = IsvMerchantSalesDetailRequest()
        if 'coupons_quantity' in d:
            o.coupons_quantity = d['coupons_quantity']
        if 'device_detail' in d:
            o.device_detail = d['device_detail']
        if 'merchant_pid' in d:
            o.merchant_pid = d['merchant_pid']
        if 'mini_appid' in d:
            o.mini_appid = d['mini_appid']
        if 'operation_place' in d:
            o.operation_place = d['operation_place']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'promotor_pid' in d:
            o.promotor_pid = d['promotor_pid']
        if 'sales_amount' in d:
            o.sales_amount = d['sales_amount']
        if 'sales_quantity' in d:
            o.sales_quantity = d['sales_quantity']
        if 'sub_promotor_pid' in d:
            o.sub_promotor_pid = d['sub_promotor_pid']
        if 'write_off_amount' in d:
            o.write_off_amount = d['write_off_amount']
        if 'write_off_quantity' in d:
            o.write_off_quantity = d['write_off_quantity']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class FinancialHolidayDayDTO(object):

    def __init__(self):
        self._day = None
        self._day_of_week = None
        self._day_type = None
        self._event_name = None
        self._gmt_modified = None
        self._month = None
        self._year = None

    @property
    def day(self):
        return self._day

    @day.setter
    def day(self, value):
        self._day = value
    @property
    def day_of_week(self):
        return self._day_of_week

    @day_of_week.setter
    def day_of_week(self, value):
        self._day_of_week = value
    @property
    def day_type(self):
        return self._day_type

    @day_type.setter
    def day_type(self, value):
        self._day_type = value
    @property
    def event_name(self):
        return self._event_name

    @event_name.setter
    def event_name(self, value):
        self._event_name = value
    @property
    def gmt_modified(self):
        return self._gmt_modified

    @gmt_modified.setter
    def gmt_modified(self, value):
        self._gmt_modified = value
    @property
    def month(self):
        return self._month

    @month.setter
    def month(self, value):
        self._month = value
    @property
    def year(self):
        return self._year

    @year.setter
    def year(self, value):
        self._year = value


    def to_alipay_dict(self):
        params = dict()
        if self.day:
            if hasattr(self.day, 'to_alipay_dict'):
                params['day'] = self.day.to_alipay_dict()
            else:
                params['day'] = self.day
        if self.day_of_week:
            if hasattr(self.day_of_week, 'to_alipay_dict'):
                params['day_of_week'] = self.day_of_week.to_alipay_dict()
            else:
                params['day_of_week'] = self.day_of_week
        if self.day_type:
            if hasattr(self.day_type, 'to_alipay_dict'):
                params['day_type'] = self.day_type.to_alipay_dict()
            else:
                params['day_type'] = self.day_type
        if self.event_name:
            if hasattr(self.event_name, 'to_alipay_dict'):
                params['event_name'] = self.event_name.to_alipay_dict()
            else:
                params['event_name'] = self.event_name
        if self.gmt_modified:
            if hasattr(self.gmt_modified, 'to_alipay_dict'):
                params['gmt_modified'] = self.gmt_modified.to_alipay_dict()
            else:
                params['gmt_modified'] = self.gmt_modified
        if self.month:
            if hasattr(self.month, 'to_alipay_dict'):
                params['month'] = self.month.to_alipay_dict()
            else:
                params['month'] = self.month
        if self.year:
            if hasattr(self.year, 'to_alipay_dict'):
                params['year'] = self.year.to_alipay_dict()
            else:
                params['year'] = self.year
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = FinancialHolidayDayDTO()
        if 'day' in d:
            o.day = d['day']
        if 'day_of_week' in d:
            o.day_of_week = d['day_of_week']
        if 'day_type' in d:
            o.day_type = d['day_type']
        if 'event_name' in d:
            o.event_name = d['event_name']
        if 'gmt_modified' in d:
            o.gmt_modified = d['gmt_modified']
        if 'month' in d:
            o.month = d['month']
        if 'year' in d:
            o.year = d['year']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ISVLogSync import ISVLogSync


class AlipayOfflineProviderMonitorLogSyncModel(object):

    def __init__(self):
        self._logs = None

    @property
    def logs(self):
        return self._logs

    @logs.setter
    def logs(self, value):
        if isinstance(value, list):
            self._logs = list()
            for i in value:
                if isinstance(i, ISVLogSync):
                    self._logs.append(i)
                else:
                    self._logs.append(ISVLogSync.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.logs:
            if isinstance(self.logs, list):
                for i in range(0, len(self.logs)):
                    element = self.logs[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.logs[i] = element.to_alipay_dict()
            if hasattr(self.logs, 'to_alipay_dict'):
                params['logs'] = self.logs.to_alipay_dict()
            else:
                params['logs'] = self.logs
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOfflineProviderMonitorLogSyncModel()
        if 'logs' in d:
            o.logs = d['logs']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class ZhimaCustomerCertificationCertifyResponse(AlipayResponse):

    def __init__(self):
        super(ZhimaCustomerCertificationCertifyResponse, self).__init__()
        self._biz_no = None
        self._failed_reason = None
        self._passed = None

    @property
    def biz_no(self):
        return self._biz_no

    @biz_no.setter
    def biz_no(self, value):
        self._biz_no = value
    @property
    def failed_reason(self):
        return self._failed_reason

    @failed_reason.setter
    def failed_reason(self, value):
        self._failed_reason = value
    @property
    def passed(self):
        return self._passed

    @passed.setter
    def passed(self, value):
        self._passed = value

    def parse_response_content(self, response_content):
        response = super(ZhimaCustomerCertificationCertifyResponse, self).parse_response_content(response_content)
        if 'biz_no' in response:
            self.biz_no = response['biz_no']
        if 'failed_reason' in response:
            self.failed_reason = response['failed_reason']
        if 'passed' in response:
            self.passed = response['passed']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoRenthouseLeaseStateSyncModel(object):

    def __init__(self):
        self._lease_ca_file = None
        self._lease_code = None
        self._lease_status = None

    @property
    def lease_ca_file(self):
        return self._lease_ca_file

    @lease_ca_file.setter
    def lease_ca_file(self, value):
        self._lease_ca_file = value
    @property
    def lease_code(self):
        return self._lease_code

    @lease_code.setter
    def lease_code(self, value):
        self._lease_code = value
    @property
    def lease_status(self):
        return self._lease_status

    @lease_status.setter
    def lease_status(self, value):
        self._lease_status = value


    def to_alipay_dict(self):
        params = dict()
        if self.lease_ca_file:
            if hasattr(self.lease_ca_file, 'to_alipay_dict'):
                params['lease_ca_file'] = self.lease_ca_file.to_alipay_dict()
            else:
                params['lease_ca_file'] = self.lease_ca_file
        if self.lease_code:
            if hasattr(self.lease_code, 'to_alipay_dict'):
                params['lease_code'] = self.lease_code.to_alipay_dict()
            else:
                params['lease_code'] = self.lease_code
        if self.lease_status:
            if hasattr(self.lease_status, 'to_alipay_dict'):
                params['lease_status'] = self.lease_status.to_alipay_dict()
            else:
                params['lease_status'] = self.lease_status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoRenthouseLeaseStateSyncModel()
        if 'lease_ca_file' in d:
            o.lease_ca_file = d['lease_ca_file']
        if 'lease_code' in d:
            o.lease_code = d['lease_code']
        if 'lease_status' in d:
            o.lease_status = d['lease_status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayAssetCardDepositbackResponse(AlipayResponse):

    def __init__(self):
        super(AlipayAssetCardDepositbackResponse, self).__init__()
        self._depositback_amount = None
        self._depositback_bill_no = None

    @property
    def depositback_amount(self):
        return self._depositback_amount

    @depositback_amount.setter
    def depositback_amount(self, value):
        self._depositback_amount = value
    @property
    def depositback_bill_no(self):
        return self._depositback_bill_no

    @depositback_bill_no.setter
    def depositback_bill_no(self, value):
        self._depositback_bill_no = value

    def parse_response_content(self, response_content):
        response = super(AlipayAssetCardDepositbackResponse, self).parse_response_content(response_content)
        if 'depositback_amount' in response:
            self.depositback_amount = response['depositback_amount']
        if 'depositback_bill_no' in response:
            self.depositback_bill_no = response['depositback_bill_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.KbOrderActivityModel import KbOrderActivityModel
from alipay.aop.api.domain.KbOrderFundsVoucherModel import KbOrderFundsVoucherModel
from alipay.aop.api.domain.KbOrderShopModel import KbOrderShopModel
from alipay.aop.api.domain.KbOrderVoucherModel import KbOrderVoucherModel


class KoubeiTradeOrderQueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiTradeOrderQueryResponse, self).__init__()
        self._activity_infos = None
        self._buyer_id = None
        self._contact = None
        self._funds_vouchers = None
        self._gmt_create = None
        self._gmt_modified = None
        self._order_no = None
        self._out_biz_no = None
        self._partner_id = None
        self._real_amount = None
        self._seller_id = None
        self._shop = None
        self._status = None
        self._total_amount = None
        self._trans_no = None
        self._vouchers = None

    @property
    def activity_infos(self):
        return self._activity_infos

    @activity_infos.setter
    def activity_infos(self, value):
        if isinstance(value, list):
            self._activity_infos = list()
            for i in value:
                if isinstance(i, KbOrderActivityModel):
                    self._activity_infos.append(i)
                else:
                    self._activity_infos.append(KbOrderActivityModel.from_alipay_dict(i))
    @property
    def buyer_id(self):
        return self._buyer_id

    @buyer_id.setter
    def buyer_id(self, value):
        self._buyer_id = value
    @property
    def contact(self):
        return self._contact

    @contact.setter
    def contact(self, value):
        self._contact = value
    @property
    def funds_vouchers(self):
        return self._funds_vouchers

    @funds_vouchers.setter
    def funds_vouchers(self, value):
        if isinstance(value, list):
            self._funds_vouchers = list()
            for i in value:
                if isinstance(i, KbOrderFundsVoucherModel):
                    self._funds_vouchers.append(i)
                else:
                    self._funds_vouchers.append(KbOrderFundsVoucherModel.from_alipay_dict(i))
    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def gmt_modified(self):
        return self._gmt_modified

    @gmt_modified.setter
    def gmt_modified(self, value):
        self._gmt_modified = value
    @property
    def order_no(self):
        return self._order_no

    @order_no.setter
    def order_no(self, value):
        self._order_no = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def real_amount(self):
        return self._real_amount

    @real_amount.setter
    def real_amount(self, value):
        self._real_amount = value
    @property
    def seller_id(self):
        return self._seller_id

    @seller_id.setter
    def seller_id(self, value):
        self._seller_id = value
    @property
    def shop(self):
        return self._shop

    @shop.setter
    def shop(self, value):
        if isinstance(value, KbOrderShopModel):
            self._shop = value
        else:
            self._shop = KbOrderShopModel.from_alipay_dict(value)
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def total_amount(self):
        return self._total_amount

    @total_amount.setter
    def total_amount(self, value):
        self._total_amount = value
    @property
    def trans_no(self):
        return self._trans_no

    @trans_no.setter
    def trans_no(self, value):
        self._trans_no = value
    @property
    def vouchers(self):
        return self._vouchers

    @vouchers.setter
    def vouchers(self, value):
        if isinstance(value, list):
            self._vouchers = list()
            for i in value:
                if isinstance(i, KbOrderVoucherModel):
                    self._vouchers.append(i)
                else:
                    self._vouchers.append(KbOrderVoucherModel.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(KoubeiTradeOrderQueryResponse, self).parse_response_content(response_content)
        if 'activity_infos' in response:
            self.activity_infos = response['activity_infos']
        if 'buyer_id' in response:
            self.buyer_id = response['buyer_id']
        if 'contact' in response:
            self.contact = response['contact']
        if 'funds_vouchers' in response:
            self.funds_vouchers = response['funds_vouchers']
        if 'gmt_create' in response:
            self.gmt_create = response['gmt_create']
        if 'gmt_modified' in response:
            self.gmt_modified = response['gmt_modified']
        if 'order_no' in response:
            self.order_no = response['order_no']
        if 'out_biz_no' in response:
            self.out_biz_no = response['out_biz_no']
        if 'partner_id' in response:
            self.partner_id = response['partner_id']
        if 'real_amount' in response:
            self.real_amount = response['real_amount']
        if 'seller_id' in response:
            self.seller_id = response['seller_id']
        if 'shop' in response:
            self.shop = response['shop']
        if 'status' in response:
            self.status = response['status']
        if 'total_amount' in response:
            self.total_amount = response['total_amount']
        if 'trans_no' in response:
            self.trans_no = response['trans_no']
        if 'vouchers' in response:
            self.vouchers = response['vouchers']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceTransportVehicleownerCampaignOnlineModel(object):

    def __init__(self):
        self._activity_id = None
        self._biz_code = None
        self._ext_info = None
        self._out_biz_id = None

    @property
    def activity_id(self):
        return self._activity_id

    @activity_id.setter
    def activity_id(self, value):
        self._activity_id = value
    @property
    def biz_code(self):
        return self._biz_code

    @biz_code.setter
    def biz_code(self, value):
        self._biz_code = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def out_biz_id(self):
        return self._out_biz_id

    @out_biz_id.setter
    def out_biz_id(self, value):
        self._out_biz_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.activity_id:
            if hasattr(self.activity_id, 'to_alipay_dict'):
                params['activity_id'] = self.activity_id.to_alipay_dict()
            else:
                params['activity_id'] = self.activity_id
        if self.biz_code:
            if hasattr(self.biz_code, 'to_alipay_dict'):
                params['biz_code'] = self.biz_code.to_alipay_dict()
            else:
                params['biz_code'] = self.biz_code
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.out_biz_id:
            if hasattr(self.out_biz_id, 'to_alipay_dict'):
                params['out_biz_id'] = self.out_biz_id.to_alipay_dict()
            else:
                params['out_biz_id'] = self.out_biz_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceTransportVehicleownerCampaignOnlineModel()
        if 'activity_id' in d:
            o.activity_id = d['activity_id']
        if 'biz_code' in d:
            o.biz_code = d['biz_code']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'out_biz_id' in d:
            o.out_biz_id = d['out_biz_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayInsSceneInsserviceprodSyncResponse(AlipayResponse):

    def __init__(self):
        super(AlipayInsSceneInsserviceprodSyncResponse, self).__init__()
        self._node_desc = None
        self._node_name = None

    @property
    def node_desc(self):
        return self._node_desc

    @node_desc.setter
    def node_desc(self, value):
        self._node_desc = value
    @property
    def node_name(self):
        return self._node_name

    @node_name.setter
    def node_name(self, value):
        self._node_name = value

    def parse_response_content(self, response_content):
        response = super(AlipayInsSceneInsserviceprodSyncResponse, self).parse_response_content(response_content)
        if 'node_desc' in response:
            self.node_desc = response['node_desc']
        if 'node_name' in response:
            self.node_name = response['node_name']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class OrderLogisticsInformationRequestDTO(object):

    def __init__(self):
        self._logistics_code = None
        self._tracking_no = None

    @property
    def logistics_code(self):
        return self._logistics_code

    @logistics_code.setter
    def logistics_code(self, value):
        self._logistics_code = value
    @property
    def tracking_no(self):
        return self._tracking_no

    @tracking_no.setter
    def tracking_no(self, value):
        self._tracking_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.logistics_code:
            if hasattr(self.logistics_code, 'to_alipay_dict'):
                params['logistics_code'] = self.logistics_code.to_alipay_dict()
            else:
                params['logistics_code'] = self.logistics_code
        if self.tracking_no:
            if hasattr(self.tracking_no, 'to_alipay_dict'):
                params['tracking_no'] = self.tracking_no.to_alipay_dict()
            else:
                params['tracking_no'] = self.tracking_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OrderLogisticsInformationRequestDTO()
        if 'logistics_code' in d:
            o.logistics_code = d['logistics_code']
        if 'tracking_no' in d:
            o.tracking_no = d['tracking_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SingleDynamicData(object):

    def __init__(self):
        self._expire = None
        self._ext_param = None
        self._priority = None
        self._unique_id = None

    @property
    def expire(self):
        return self._expire

    @expire.setter
    def expire(self, value):
        self._expire = value
    @property
    def ext_param(self):
        return self._ext_param

    @ext_param.setter
    def ext_param(self, value):
        self._ext_param = value
    @property
    def priority(self):
        return self._priority

    @priority.setter
    def priority(self, value):
        self._priority = value
    @property
    def unique_id(self):
        return self._unique_id

    @unique_id.setter
    def unique_id(self, value):
        self._unique_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.expire:
            if hasattr(self.expire, 'to_alipay_dict'):
                params['expire'] = self.expire.to_alipay_dict()
            else:
                params['expire'] = self.expire
        if self.ext_param:
            if hasattr(self.ext_param, 'to_alipay_dict'):
                params['ext_param'] = self.ext_param.to_alipay_dict()
            else:
                params['ext_param'] = self.ext_param
        if self.priority:
            if hasattr(self.priority, 'to_alipay_dict'):
                params['priority'] = self.priority.to_alipay_dict()
            else:
                params['priority'] = self.priority
        if self.unique_id:
            if hasattr(self.unique_id, 'to_alipay_dict'):
                params['unique_id'] = self.unique_id.to_alipay_dict()
            else:
                params['unique_id'] = self.unique_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SingleDynamicData()
        if 'expire' in d:
            o.expire = d['expire']
        if 'ext_param' in d:
            o.ext_param = d['ext_param']
        if 'priority' in d:
            o.priority = d['priority']
        if 'unique_id' in d:
            o.unique_id = d['unique_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BrandRegistrationInfo(object):

    def __init__(self):
        self._end_date = None
        self._reg_materials = None
        self._reg_number = None
        self._registrant = None
        self._start_date = None

    @property
    def end_date(self):
        return self._end_date

    @end_date.setter
    def end_date(self, value):
        self._end_date = value
    @property
    def reg_materials(self):
        return self._reg_materials

    @reg_materials.setter
    def reg_materials(self, value):
        if isinstance(value, list):
            self._reg_materials = list()
            for i in value:
                self._reg_materials.append(i)
    @property
    def reg_number(self):
        return self._reg_number

    @reg_number.setter
    def reg_number(self, value):
        self._reg_number = value
    @property
    def registrant(self):
        return self._registrant

    @registrant.setter
    def registrant(self, value):
        self._registrant = value
    @property
    def start_date(self):
        return self._start_date

    @start_date.setter
    def start_date(self, value):
        self._start_date = value


    def to_alipay_dict(self):
        params = dict()
        if self.end_date:
            if hasattr(self.end_date, 'to_alipay_dict'):
                params['end_date'] = self.end_date.to_alipay_dict()
            else:
                params['end_date'] = self.end_date
        if self.reg_materials:
            if isinstance(self.reg_materials, list):
                for i in range(0, len(self.reg_materials)):
                    element = self.reg_materials[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.reg_materials[i] = element.to_alipay_dict()
            if hasattr(self.reg_materials, 'to_alipay_dict'):
                params['reg_materials'] = self.reg_materials.to_alipay_dict()
            else:
                params['reg_materials'] = self.reg_materials
        if self.reg_number:
            if hasattr(self.reg_number, 'to_alipay_dict'):
                params['reg_number'] = self.reg_number.to_alipay_dict()
            else:
                params['reg_number'] = self.reg_number
        if self.registrant:
            if hasattr(self.registrant, 'to_alipay_dict'):
                params['registrant'] = self.registrant.to_alipay_dict()
            else:
                params['registrant'] = self.registrant
        if self.start_date:
            if hasattr(self.start_date, 'to_alipay_dict'):
                params['start_date'] = self.start_date.to_alipay_dict()
            else:
                params['start_date'] = self.start_date
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BrandRegistrationInfo()
        if 'end_date' in d:
            o.end_date = d['end_date']
        if 'reg_materials' in d:
            o.reg_materials = d['reg_materials']
        if 'reg_number' in d:
            o.reg_number = d['reg_number']
        if 'registrant' in d:
            o.registrant = d['registrant']
        if 'start_date' in d:
            o.start_date = d['start_date']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.OverseasExtendParams import OverseasExtendParams


class AlipayTradeOverseasSettleModel(object):

    def __init__(self):
        self._amount = None
        self._extend_params = None
        self._foreign_settle_currency = None
        self._out_request_no = None
        self._trade_no = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def extend_params(self):
        return self._extend_params

    @extend_params.setter
    def extend_params(self, value):
        if isinstance(value, OverseasExtendParams):
            self._extend_params = value
        else:
            self._extend_params = OverseasExtendParams.from_alipay_dict(value)
    @property
    def foreign_settle_currency(self):
        return self._foreign_settle_currency

    @foreign_settle_currency.setter
    def foreign_settle_currency(self, value):
        self._foreign_settle_currency = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.extend_params:
            if hasattr(self.extend_params, 'to_alipay_dict'):
                params['extend_params'] = self.extend_params.to_alipay_dict()
            else:
                params['extend_params'] = self.extend_params
        if self.foreign_settle_currency:
            if hasattr(self.foreign_settle_currency, 'to_alipay_dict'):
                params['foreign_settle_currency'] = self.foreign_settle_currency.to_alipay_dict()
            else:
                params['foreign_settle_currency'] = self.foreign_settle_currency
        if self.out_request_no:
            if hasattr(self.out_request_no, 'to_alipay_dict'):
                params['out_request_no'] = self.out_request_no.to_alipay_dict()
            else:
                params['out_request_no'] = self.out_request_no
        if self.trade_no:
            if hasattr(self.trade_no, 'to_alipay_dict'):
                params['trade_no'] = self.trade_no.to_alipay_dict()
            else:
                params['trade_no'] = self.trade_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayTradeOverseasSettleModel()
        if 'amount' in d:
            o.amount = d['amount']
        if 'extend_params' in d:
            o.extend_params = d['extend_params']
        if 'foreign_settle_currency' in d:
            o.foreign_settle_currency = d['foreign_settle_currency']
        if 'out_request_no' in d:
            o.out_request_no = d['out_request_no']
        if 'trade_no' in d:
            o.trade_no = d['trade_no']
        return o





# -*- coding: utf-8 -*-
'''
Created on 2017-12-20

@author: liuqun
'''
import base64

from alipay.aop.api.constant.CommonConstants import PYTHON_VERSION_3
from alipay.aop.api.exception.Exception import RequestException
from Crypto.Cipher import AES


BLOCK_SIZE = AES.block_size
pad = lambda s, length: s + (BLOCK_SIZE - length % BLOCK_SIZE) * chr(BLOCK_SIZE - length % BLOCK_SIZE)
unpad = lambda s: s[:-ord(s[len(s) - 1:])]


def encrypt_content(content, encrypt_type, encrypt_key, charset):
    if "AES" == encrypt_type.upper():
        return aes_encrypt_content(content, encrypt_key, charset)
    raise RequestException("当前不支持该算法类型encrypt_type=" + encrypt_type)


def aes_encrypt_content(content, encrypt_key, charset):
    length = None
    if PYTHON_VERSION_3:
        length = len(bytes(content, encoding=charset))
    else:
        length = len(bytes(content))
    padded_content = pad(content, length)
    iv = '\0' * BLOCK_SIZE
    cryptor = AES.new(base64.b64decode(encrypt_key), AES.MODE_CBC, iv)
    encrypted_content = cryptor.encrypt(padded_content)
    encrypted_content = base64.b64encode(encrypted_content)
    if PYTHON_VERSION_3:
        encrypted_content = str(encrypted_content, encoding=charset)
    return encrypted_content


def decrypt_content(encrypted_content, encrypt_type, encrypt_key, charset):
    if "AES" == encrypt_type.upper():
        return aes_decrypt_content(encrypted_content, encrypt_key, charset)
    raise RequestException("当前不支持该算法类型encrypt_type=" + encrypt_type)


def aes_decrypt_content(encrypted_content, encrypt_key, charset):
    encrypted_content = base64.b64decode(encrypted_content)
    iv = '\0' * BLOCK_SIZE
    cryptor = AES.new(base64.b64decode(encrypt_key), AES.MODE_CBC, iv)
    content = unpad(cryptor.decrypt(encrypted_content))
    if PYTHON_VERSION_3:
        content = content.decode(charset)
    return content



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayPassCodeAddResponse(AlipayResponse):

    def __init__(self):
        super(AlipayPassCodeAddResponse, self).__init__()
        self._biz_result = None
        self._error_code = None
        self._success = None

    @property
    def biz_result(self):
        return self._biz_result

    @biz_result.setter
    def biz_result(self, value):
        if isinstance(value, list):
            self._biz_result = list()
            for i in value:
                self._biz_result.append(i)
    @property
    def error_code(self):
        return self._error_code

    @error_code.setter
    def error_code(self, value):
        self._error_code = value
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value

    def parse_response_content(self, response_content):
        response = super(AlipayPassCodeAddResponse, self).parse_response_content(response_content)
        if 'biz_result' in response:
            self.biz_result = response['biz_result']
        if 'error_code' in response:
            self.error_code = response['error_code']
        if 'success' in response:
            self.success = response['success']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZhimaCreditEpSceneTradeConsultModel(object):

    def __init__(self):
        self._apply_amount = None
        self._biz_ext_param = None
        self._customer_rating_no = None
        self._out_order_no = None
        self._product_code = None

    @property
    def apply_amount(self):
        return self._apply_amount

    @apply_amount.setter
    def apply_amount(self, value):
        self._apply_amount = value
    @property
    def biz_ext_param(self):
        return self._biz_ext_param

    @biz_ext_param.setter
    def biz_ext_param(self, value):
        self._biz_ext_param = value
    @property
    def customer_rating_no(self):
        return self._customer_rating_no

    @customer_rating_no.setter
    def customer_rating_no(self, value):
        self._customer_rating_no = value
    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.apply_amount:
            if hasattr(self.apply_amount, 'to_alipay_dict'):
                params['apply_amount'] = self.apply_amount.to_alipay_dict()
            else:
                params['apply_amount'] = self.apply_amount
        if self.biz_ext_param:
            if hasattr(self.biz_ext_param, 'to_alipay_dict'):
                params['biz_ext_param'] = self.biz_ext_param.to_alipay_dict()
            else:
                params['biz_ext_param'] = self.biz_ext_param
        if self.customer_rating_no:
            if hasattr(self.customer_rating_no, 'to_alipay_dict'):
                params['customer_rating_no'] = self.customer_rating_no.to_alipay_dict()
            else:
                params['customer_rating_no'] = self.customer_rating_no
        if self.out_order_no:
            if hasattr(self.out_order_no, 'to_alipay_dict'):
                params['out_order_no'] = self.out_order_no.to_alipay_dict()
            else:
                params['out_order_no'] = self.out_order_no
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaCreditEpSceneTradeConsultModel()
        if 'apply_amount' in d:
            o.apply_amount = d['apply_amount']
        if 'biz_ext_param' in d:
            o.biz_ext_param = d['biz_ext_param']
        if 'customer_rating_no' in d:
            o.customer_rating_no = d['customer_rating_no']
        if 'out_order_no' in d:
            o.out_order_no = d['out_order_no']
        if 'product_code' in d:
            o.product_code = d['product_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ParkingOrderPromo import ParkingOrderPromo


class AlipayEcoMycarParkingPayCancelModel(object):

    def __init__(self):
        self._in_time = None
        self._out_order_no = None
        self._out_serial_no = None
        self._out_time = None
        self._parking_id = None
        self._pay_scene = None
        self._plate_color = None
        self._plate_no = None
        self._promo = None
        self._seller_id = None
        self._serial_no = None
        self._subject = None
        self._total_amount = None

    @property
    def in_time(self):
        return self._in_time

    @in_time.setter
    def in_time(self, value):
        self._in_time = value
    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def out_serial_no(self):
        return self._out_serial_no

    @out_serial_no.setter
    def out_serial_no(self, value):
        self._out_serial_no = value
    @property
    def out_time(self):
        return self._out_time

    @out_time.setter
    def out_time(self, value):
        self._out_time = value
    @property
    def parking_id(self):
        return self._parking_id

    @parking_id.setter
    def parking_id(self, value):
        self._parking_id = value
    @property
    def pay_scene(self):
        return self._pay_scene

    @pay_scene.setter
    def pay_scene(self, value):
        self._pay_scene = value
    @property
    def plate_color(self):
        return self._plate_color

    @plate_color.setter
    def plate_color(self, value):
        self._plate_color = value
    @property
    def plate_no(self):
        return self._plate_no

    @plate_no.setter
    def plate_no(self, value):
        self._plate_no = value
    @property
    def promo(self):
        return self._promo

    @promo.setter
    def promo(self, value):
        if isinstance(value, ParkingOrderPromo):
            self._promo = value
        else:
            self._promo = ParkingOrderPromo.from_alipay_dict(value)
    @property
    def seller_id(self):
        return self._seller_id

    @seller_id.setter
    def seller_id(self, value):
        self._seller_id = value
    @property
    def serial_no(self):
        return self._serial_no

    @serial_no.setter
    def serial_no(self, value):
        self._serial_no = value
    @property
    def subject(self):
        return self._subject

    @subject.setter
    def subject(self, value):
        self._subject = value
    @property
    def total_amount(self):
        return self._total_amount

    @total_amount.setter
    def total_amount(self, value):
        self._total_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.in_time:
            if hasattr(self.in_time, 'to_alipay_dict'):
                params['in_time'] = self.in_time.to_alipay_dict()
            else:
                params['in_time'] = self.in_time
        if self.out_order_no:
            if hasattr(self.out_order_no, 'to_alipay_dict'):
                params['out_order_no'] = self.out_order_no.to_alipay_dict()
            else:
                params['out_order_no'] = self.out_order_no
        if self.out_serial_no:
            if hasattr(self.out_serial_no, 'to_alipay_dict'):
                params['out_serial_no'] = self.out_serial_no.to_alipay_dict()
            else:
                params['out_serial_no'] = self.out_serial_no
        if self.out_time:
            if hasattr(self.out_time, 'to_alipay_dict'):
                params['out_time'] = self.out_time.to_alipay_dict()
            else:
                params['out_time'] = self.out_time
        if self.parking_id:
            if hasattr(self.parking_id, 'to_alipay_dict'):
                params['parking_id'] = self.parking_id.to_alipay_dict()
            else:
                params['parking_id'] = self.parking_id
        if self.pay_scene:
            if hasattr(self.pay_scene, 'to_alipay_dict'):
                params['pay_scene'] = self.pay_scene.to_alipay_dict()
            else:
                params['pay_scene'] = self.pay_scene
        if self.plate_color:
            if hasattr(self.plate_color, 'to_alipay_dict'):
                params['plate_color'] = self.plate_color.to_alipay_dict()
            else:
                params['plate_color'] = self.plate_color
        if self.plate_no:
            if hasattr(self.plate_no, 'to_alipay_dict'):
                params['plate_no'] = self.plate_no.to_alipay_dict()
            else:
                params['plate_no'] = self.plate_no
        if self.promo:
            if hasattr(self.promo, 'to_alipay_dict'):
                params['promo'] = self.promo.to_alipay_dict()
            else:
                params['promo'] = self.promo
        if self.seller_id:
            if hasattr(self.seller_id, 'to_alipay_dict'):
                params['seller_id'] = self.seller_id.to_alipay_dict()
            else:
                params['seller_id'] = self.seller_id
        if self.serial_no:
            if hasattr(self.serial_no, 'to_alipay_dict'):
                params['serial_no'] = self.serial_no.to_alipay_dict()
            else:
                params['serial_no'] = self.serial_no
        if self.subject:
            if hasattr(self.subject, 'to_alipay_dict'):
                params['subject'] = self.subject.to_alipay_dict()
            else:
                params['subject'] = self.subject
        if self.total_amount:
            if hasattr(self.total_amount, 'to_alipay_dict'):
                params['total_amount'] = self.total_amount.to_alipay_dict()
            else:
                params['total_amount'] = self.total_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoMycarParkingPayCancelModel()
        if 'in_time' in d:
            o.in_time = d['in_time']
        if 'out_order_no' in d:
            o.out_order_no = d['out_order_no']
        if 'out_serial_no' in d:
            o.out_serial_no = d['out_serial_no']
        if 'out_time' in d:
            o.out_time = d['out_time']
        if 'parking_id' in d:
            o.parking_id = d['parking_id']
        if 'pay_scene' in d:
            o.pay_scene = d['pay_scene']
        if 'plate_color' in d:
            o.plate_color = d['plate_color']
        if 'plate_no' in d:
            o.plate_no = d['plate_no']
        if 'promo' in d:
            o.promo = d['promo']
        if 'seller_id' in d:
            o.seller_id = d['seller_id']
        if 'serial_no' in d:
            o.serial_no = d['serial_no']
        if 'subject' in d:
            o.subject = d['subject']
        if 'total_amount' in d:
            o.total_amount = d['total_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BizFundReportResult(object):

    def __init__(self):
        self._alipay_amount = None
        self._batch_type = None
        self._biz_type = None
        self._biz_type_desc = None
        self._charge_fee = None
        self._gmt_create = None
        self._instruction_id = None
        self._memo = None
        self._no_mbill_encrypt = None
        self._order_id = None
        self._pay_amount = None
        self._payee_card_no = None
        self._payee_full_name = None
        self._payee_fund_type = None
        self._payee_fund_type_desc = None
        self._payee_inst_name = None
        self._payee_login_email = None
        self._payee_name = None
        self._payer_fund_type = None
        self._payer_fund_type_desc = None
        self._refund_amount = None
        self._show_detail = None
        self._show_voucher = None
        self._source = None
        self._status = None
        self._status_desc = None
        self._sub_biz_type = None
        self._sub_biz_type_desc = None

    @property
    def alipay_amount(self):
        return self._alipay_amount

    @alipay_amount.setter
    def alipay_amount(self, value):
        self._alipay_amount = value
    @property
    def batch_type(self):
        return self._batch_type

    @batch_type.setter
    def batch_type(self, value):
        self._batch_type = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def biz_type_desc(self):
        return self._biz_type_desc

    @biz_type_desc.setter
    def biz_type_desc(self, value):
        self._biz_type_desc = value
    @property
    def charge_fee(self):
        return self._charge_fee

    @charge_fee.setter
    def charge_fee(self, value):
        self._charge_fee = value
    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def instruction_id(self):
        return self._instruction_id

    @instruction_id.setter
    def instruction_id(self, value):
        self._instruction_id = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def no_mbill_encrypt(self):
        return self._no_mbill_encrypt

    @no_mbill_encrypt.setter
    def no_mbill_encrypt(self, value):
        self._no_mbill_encrypt = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def pay_amount(self):
        return self._pay_amount

    @pay_amount.setter
    def pay_amount(self, value):
        self._pay_amount = value
    @property
    def payee_card_no(self):
        return self._payee_card_no

    @payee_card_no.setter
    def payee_card_no(self, value):
        self._payee_card_no = value
    @property
    def payee_full_name(self):
        return self._payee_full_name

    @payee_full_name.setter
    def payee_full_name(self, value):
        self._payee_full_name = value
    @property
    def payee_fund_type(self):
        return self._payee_fund_type

    @payee_fund_type.setter
    def payee_fund_type(self, value):
        self._payee_fund_type = value
    @property
    def payee_fund_type_desc(self):
        return self._payee_fund_type_desc

    @payee_fund_type_desc.setter
    def payee_fund_type_desc(self, value):
        self._payee_fund_type_desc = value
    @property
    def payee_inst_name(self):
        return self._payee_inst_name

    @payee_inst_name.setter
    def payee_inst_name(self, value):
        self._payee_inst_name = value
    @property
    def payee_login_email(self):
        return self._payee_login_email

    @payee_login_email.setter
    def payee_login_email(self, value):
        self._payee_login_email = value
    @property
    def payee_name(self):
        return self._payee_name

    @payee_name.setter
    def payee_name(self, value):
        self._payee_name = value
    @property
    def payer_fund_type(self):
        return self._payer_fund_type

    @payer_fund_type.setter
    def payer_fund_type(self, value):
        self._payer_fund_type = value
    @property
    def payer_fund_type_desc(self):
        return self._payer_fund_type_desc

    @payer_fund_type_desc.setter
    def payer_fund_type_desc(self, value):
        self._payer_fund_type_desc = value
    @property
    def refund_amount(self):
        return self._refund_amount

    @refund_amount.setter
    def refund_amount(self, value):
        self._refund_amount = value
    @property
    def show_detail(self):
        return self._show_detail

    @show_detail.setter
    def show_detail(self, value):
        self._show_detail = value
    @property
    def show_voucher(self):
        return self._show_voucher

    @show_voucher.setter
    def show_voucher(self, value):
        self._show_voucher = value
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def status_desc(self):
        return self._status_desc

    @status_desc.setter
    def status_desc(self, value):
        self._status_desc = value
    @property
    def sub_biz_type(self):
        return self._sub_biz_type

    @sub_biz_type.setter
    def sub_biz_type(self, value):
        self._sub_biz_type = value
    @property
    def sub_biz_type_desc(self):
        return self._sub_biz_type_desc

    @sub_biz_type_desc.setter
    def sub_biz_type_desc(self, value):
        self._sub_biz_type_desc = value


    def to_alipay_dict(self):
        params = dict()
        if self.alipay_amount:
            if hasattr(self.alipay_amount, 'to_alipay_dict'):
                params['alipay_amount'] = self.alipay_amount.to_alipay_dict()
            else:
                params['alipay_amount'] = self.alipay_amount
        if self.batch_type:
            if hasattr(self.batch_type, 'to_alipay_dict'):
                params['batch_type'] = self.batch_type.to_alipay_dict()
            else:
                params['batch_type'] = self.batch_type
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.biz_type_desc:
            if hasattr(self.biz_type_desc, 'to_alipay_dict'):
                params['biz_type_desc'] = self.biz_type_desc.to_alipay_dict()
            else:
                params['biz_type_desc'] = self.biz_type_desc
        if self.charge_fee:
            if hasattr(self.charge_fee, 'to_alipay_dict'):
                params['charge_fee'] = self.charge_fee.to_alipay_dict()
            else:
                params['charge_fee'] = self.charge_fee
        if self.gmt_create:
            if hasattr(self.gmt_create, 'to_alipay_dict'):
                params['gmt_create'] = self.gmt_create.to_alipay_dict()
            else:
                params['gmt_create'] = self.gmt_create
        if self.instruction_id:
            if hasattr(self.instruction_id, 'to_alipay_dict'):
                params['instruction_id'] = self.instruction_id.to_alipay_dict()
            else:
                params['instruction_id'] = self.instruction_id
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.no_mbill_encrypt:
            if hasattr(self.no_mbill_encrypt, 'to_alipay_dict'):
                params['no_mbill_encrypt'] = self.no_mbill_encrypt.to_alipay_dict()
            else:
                params['no_mbill_encrypt'] = self.no_mbill_encrypt
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        if self.pay_amount:
            if hasattr(self.pay_amount, 'to_alipay_dict'):
                params['pay_amount'] = self.pay_amount.to_alipay_dict()
            else:
                params['pay_amount'] = self.pay_amount
        if self.payee_card_no:
            if hasattr(self.payee_card_no, 'to_alipay_dict'):
                params['payee_card_no'] = self.payee_card_no.to_alipay_dict()
            else:
                params['payee_card_no'] = self.payee_card_no
        if self.payee_full_name:
            if hasattr(self.payee_full_name, 'to_alipay_dict'):
                params['payee_full_name'] = self.payee_full_name.to_alipay_dict()
            else:
                params['payee_full_name'] = self.payee_full_name
        if self.payee_fund_type:
            if hasattr(self.payee_fund_type, 'to_alipay_dict'):
                params['payee_fund_type'] = self.payee_fund_type.to_alipay_dict()
            else:
                params['payee_fund_type'] = self.payee_fund_type
        if self.payee_fund_type_desc:
            if hasattr(self.payee_fund_type_desc, 'to_alipay_dict'):
                params['payee_fund_type_desc'] = self.payee_fund_type_desc.to_alipay_dict()
            else:
                params['payee_fund_type_desc'] = self.payee_fund_type_desc
        if self.payee_inst_name:
            if hasattr(self.payee_inst_name, 'to_alipay_dict'):
                params['payee_inst_name'] = self.payee_inst_name.to_alipay_dict()
            else:
                params['payee_inst_name'] = self.payee_inst_name
        if self.payee_login_email:
            if hasattr(self.payee_login_email, 'to_alipay_dict'):
                params['payee_login_email'] = self.payee_login_email.to_alipay_dict()
            else:
                params['payee_login_email'] = self.payee_login_email
        if self.payee_name:
            if hasattr(self.payee_name, 'to_alipay_dict'):
                params['payee_name'] = self.payee_name.to_alipay_dict()
            else:
                params['payee_name'] = self.payee_name
        if self.payer_fund_type:
            if hasattr(self.payer_fund_type, 'to_alipay_dict'):
                params['payer_fund_type'] = self.payer_fund_type.to_alipay_dict()
            else:
                params['payer_fund_type'] = self.payer_fund_type
        if self.payer_fund_type_desc:
            if hasattr(self.payer_fund_type_desc, 'to_alipay_dict'):
                params['payer_fund_type_desc'] = self.payer_fund_type_desc.to_alipay_dict()
            else:
                params['payer_fund_type_desc'] = self.payer_fund_type_desc
        if self.refund_amount:
            if hasattr(self.refund_amount, 'to_alipay_dict'):
                params['refund_amount'] = self.refund_amount.to_alipay_dict()
            else:
                params['refund_amount'] = self.refund_amount
        if self.show_detail:
            if hasattr(self.show_detail, 'to_alipay_dict'):
                params['show_detail'] = self.show_detail.to_alipay_dict()
            else:
                params['show_detail'] = self.show_detail
        if self.show_voucher:
            if hasattr(self.show_voucher, 'to_alipay_dict'):
                params['show_voucher'] = self.show_voucher.to_alipay_dict()
            else:
                params['show_voucher'] = self.show_voucher
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.status_desc:
            if hasattr(self.status_desc, 'to_alipay_dict'):
                params['status_desc'] = self.status_desc.to_alipay_dict()
            else:
                params['status_desc'] = self.status_desc
        if self.sub_biz_type:
            if hasattr(self.sub_biz_type, 'to_alipay_dict'):
                params['sub_biz_type'] = self.sub_biz_type.to_alipay_dict()
            else:
                params['sub_biz_type'] = self.sub_biz_type
        if self.sub_biz_type_desc:
            if hasattr(self.sub_biz_type_desc, 'to_alipay_dict'):
                params['sub_biz_type_desc'] = self.sub_biz_type_desc.to_alipay_dict()
            else:
                params['sub_biz_type_desc'] = self.sub_biz_type_desc
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BizFundReportResult()
        if 'alipay_amount' in d:
            o.alipay_amount = d['alipay_amount']
        if 'batch_type' in d:
            o.batch_type = d['batch_type']
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'biz_type_desc' in d:
            o.biz_type_desc = d['biz_type_desc']
        if 'charge_fee' in d:
            o.charge_fee = d['charge_fee']
        if 'gmt_create' in d:
            o.gmt_create = d['gmt_create']
        if 'instruction_id' in d:
            o.instruction_id = d['instruction_id']
        if 'memo' in d:
            o.memo = d['memo']
        if 'no_mbill_encrypt' in d:
            o.no_mbill_encrypt = d['no_mbill_encrypt']
        if 'order_id' in d:
            o.order_id = d['order_id']
        if 'pay_amount' in d:
            o.pay_amount = d['pay_amount']
        if 'payee_card_no' in d:
            o.payee_card_no = d['payee_card_no']
        if 'payee_full_name' in d:
            o.payee_full_name = d['payee_full_name']
        if 'payee_fund_type' in d:
            o.payee_fund_type = d['payee_fund_type']
        if 'payee_fund_type_desc' in d:
            o.payee_fund_type_desc = d['payee_fund_type_desc']
        if 'payee_inst_name' in d:
            o.payee_inst_name = d['payee_inst_name']
        if 'payee_login_email' in d:
            o.payee_login_email = d['payee_login_email']
        if 'payee_name' in d:
            o.payee_name = d['payee_name']
        if 'payer_fund_type' in d:
            o.payer_fund_type = d['payer_fund_type']
        if 'payer_fund_type_desc' in d:
            o.payer_fund_type_desc = d['payer_fund_type_desc']
        if 'refund_amount' in d:
            o.refund_amount = d['refund_amount']
        if 'show_detail' in d:
            o.show_detail = d['show_detail']
        if 'show_voucher' in d:
            o.show_voucher = d['show_voucher']
        if 'source' in d:
            o.source = d['source']
        if 'status' in d:
            o.status = d['status']
        if 'status_desc' in d:
            o.status_desc = d['status_desc']
        if 'sub_biz_type' in d:
            o.sub_biz_type = d['sub_biz_type']
        if 'sub_biz_type_desc' in d:
            o.sub_biz_type_desc = d['sub_biz_type_desc']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ScenicExplanationPoint import ScenicExplanationPoint


class AlipayCommerceDataScenicExplanationSyncModel(object):

    def __init__(self):
        self._scenic_app_id = None
        self._scenic_outer_id = None
        self._scenic_points = None
        self._service_plugin_id = None

    @property
    def scenic_app_id(self):
        return self._scenic_app_id

    @scenic_app_id.setter
    def scenic_app_id(self, value):
        self._scenic_app_id = value
    @property
    def scenic_outer_id(self):
        return self._scenic_outer_id

    @scenic_outer_id.setter
    def scenic_outer_id(self, value):
        self._scenic_outer_id = value
    @property
    def scenic_points(self):
        return self._scenic_points

    @scenic_points.setter
    def scenic_points(self, value):
        if isinstance(value, list):
            self._scenic_points = list()
            for i in value:
                if isinstance(i, ScenicExplanationPoint):
                    self._scenic_points.append(i)
                else:
                    self._scenic_points.append(ScenicExplanationPoint.from_alipay_dict(i))
    @property
    def service_plugin_id(self):
        return self._service_plugin_id

    @service_plugin_id.setter
    def service_plugin_id(self, value):
        self._service_plugin_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.scenic_app_id:
            if hasattr(self.scenic_app_id, 'to_alipay_dict'):
                params['scenic_app_id'] = self.scenic_app_id.to_alipay_dict()
            else:
                params['scenic_app_id'] = self.scenic_app_id
        if self.scenic_outer_id:
            if hasattr(self.scenic_outer_id, 'to_alipay_dict'):
                params['scenic_outer_id'] = self.scenic_outer_id.to_alipay_dict()
            else:
                params['scenic_outer_id'] = self.scenic_outer_id
        if self.scenic_points:
            if isinstance(self.scenic_points, list):
                for i in range(0, len(self.scenic_points)):
                    element = self.scenic_points[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.scenic_points[i] = element.to_alipay_dict()
            if hasattr(self.scenic_points, 'to_alipay_dict'):
                params['scenic_points'] = self.scenic_points.to_alipay_dict()
            else:
                params['scenic_points'] = self.scenic_points
        if self.service_plugin_id:
            if hasattr(self.service_plugin_id, 'to_alipay_dict'):
                params['service_plugin_id'] = self.service_plugin_id.to_alipay_dict()
            else:
                params['service_plugin_id'] = self.service_plugin_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceDataScenicExplanationSyncModel()
        if 'scenic_app_id' in d:
            o.scenic_app_id = d['scenic_app_id']
        if 'scenic_outer_id' in d:
            o.scenic_outer_id = d['scenic_outer_id']
        if 'scenic_points' in d:
            o.scenic_points = d['scenic_points']
        if 'service_plugin_id' in d:
            o.service_plugin_id = d['service_plugin_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommerceIotServiceutilBuildtextSendResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceIotServiceutilBuildtextSendResponse, self).__init__()
        self._audio_id = None
        self._md_5 = None
        self._url = None

    @property
    def audio_id(self):
        return self._audio_id

    @audio_id.setter
    def audio_id(self, value):
        self._audio_id = value
    @property
    def md_5(self):
        return self._md_5

    @md_5.setter
    def md_5(self, value):
        self._md_5 = value
    @property
    def url(self):
        return self._url

    @url.setter
    def url(self, value):
        self._url = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceIotServiceutilBuildtextSendResponse, self).parse_response_content(response_content)
        if 'audio_id' in response:
            self.audio_id = response['audio_id']
        if 'md_5' in response:
            self.md_5 = response['md_5']
        if 'url' in response:
            self.url = response['url']
